#!/usr/bin/env node
const { execSync } = require("child_process");

/**
 * Gets the latest published npm version for the specified package and version prefix
 *
 * Example usage:
 *    get-latest-version @liblab/cli 0.0.1-dev.
 * Example output:
 *    @liblab/cli@0.0.1-dev.202
 *
 */

function getLatestVersion(versions) {
  return [
    0,
    ...versions
      .filter((version) => version.startsWith(process.argv[3]))
      .map((version) => parseInt(version.replace(process.argv[3], ""))),
  ].sort((a, b) => b - a)[0];
}

const npmVersions = JSON.parse(execSync(`npm view ${process.argv[2]} versions --json`));

console.log(`${process.argv[2]}@${process.argv[3]}${getLatestVersion(npmVersions)}`);
