"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usesPagination = usesPagination;
exports.usesStreaming = usesStreaming;
const endpoint_customizations_1 = require("../services/spec/endpoint-customizations");
/**
 * Checks whether the provided configuration enables pagination for any of the API endpoints.
 *
 * @param config - The configuration object that may contain endpoint customizations.
 * @returns `true` if pagination is used for any endpoint, otherwise `false`.
 *
 * This function evaluates endpoint customizations and looks for the `pagination` setting.
 * If `pagination` is enabled in any endpoint, the function returns `true`.
 */
function usesPagination(config) {
    var _a;
    const endpointCustomizations = (_a = config.customizations) === null || _a === void 0 ? void 0 : _a.endpointCustomizations;
    if (!endpointCustomizations) {
        return false;
    }
    if (typeof endpointCustomizations === 'string') {
        return false;
    }
    let doesUsePagination = false;
    (0, endpoint_customizations_1.forEachEndpointCustomization)(endpointCustomizations, (params) => {
        doesUsePagination = doesUsePagination || Boolean(params.pagination);
    });
    return doesUsePagination;
}
function usesStreaming(config) {
    var _a;
    const endpointCustomizations = (_a = config.customizations) === null || _a === void 0 ? void 0 : _a.endpointCustomizations;
    if (!endpointCustomizations || typeof endpointCustomizations === 'string') {
        return false;
    }
    let doesUseStreaming = false;
    (0, endpoint_customizations_1.forEachEndpointCustomization)(endpointCustomizations, (params) => {
        doesUseStreaming = doesUseStreaming || Boolean(params.streaming);
    });
    return doesUseStreaming;
}
