"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const analytics_provider_1 = tslib_1.__importDefault(require("../../lib/analytics-provider"));
const liblab_1 = require("../../lib/liblab");
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const authenticate_user_1 = require("../../utils/authenticate-user");
const get_limited_console_error_1 = tslib_1.__importDefault(require("../../utils/get-limited-console-error"));
const keypress_utils_1 = require("../../utils/keypress.utils");
const wrapper_utils_1 = require("../../utils/wrapper.utils");
const base_command_1 = require("../base-command");
class ChangePassword extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async run() {
        const currentUser = await (0, authenticate_user_1.authenticateUser)({ liblabClientProvider: this.liblabClient });
        this.analytics = new analytics_provider_1.default({
            commandParams: { argv: this.argv, config: this.config, name: 'command change-password' },
            commandType: ChangePassword,
            currentUser,
        });
        const changePasswordResponse = await (0, liblab_1.changePassword)();
        if (!changePasswordResponse) {
            const reason = 'Unable to get change password url';
            await this.analytics.logEvent({ reason, status: 'failed' });
            this.error(reason);
        }
        const { url } = changePasswordResponse;
        this.log('A browser will now open where you can change your password');
        this.log(`If you have any issues you may also use the link: ${url}`);
        await wrapper_utils_1.window.open(url);
        await (0, keypress_utils_1.pressAnyKey)('Once you have changed your password, press any key to continue');
        try {
            await this.liblabClient.logout();
            this.log('You have been logged out. Please log in again with your new password.');
            await this.analytics.logEvent({ status: 'succeed' });
        }
        catch (error) {
            const reason = (error === null || error === void 0 ? void 0 : error.message) || 'Unable to log out';
            await this.analytics.logEvent({ error, reason, status: 'failed' });
            this.error((0, get_limited_console_error_1.default)(reason));
        }
        return true;
    }
}
ChangePassword.description = 'Retrieve url to change password for the current user';
ChangePassword.examples = ['liblab change-password'];
ChangePassword.tag = command_tags_enum_1.default.AUTH;
exports.default = ChangePassword;
