"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const help_1 = tslib_1.__importDefault(require("../../help"));
const analytics_provider_1 = tslib_1.__importDefault(require("../../lib/analytics-provider"));
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const base_command_1 = require("../base-command");
class Help extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async run() {
        const { flags } = await this.parse(Help);
        const help = new help_1.default(this.config, { all: flags['nested-commands'] });
        await help.showHelp(this.argv);
        await this.liblabClient.init();
        if (!this.liblabClient.currentUser) {
            return;
        }
        this.analytics = new analytics_provider_1.default({
            commandParams: {
                argv: this.argv,
                config: this.config,
                name: 'command help',
            },
            commandType: Help,
            currentUser: this.liblabClient.currentUser,
        });
        await this.analytics.logEvent({ status: 'succeed' });
    }
}
Help.args = {
    commands: core_1.Args.string({ description: 'Command to show help for.', required: false }),
};
Help.description = 'Display help for <%= config.bin %>.';
Help.flags = {
    'nested-commands': core_1.Flags.boolean({
        char: 'n',
        description: 'Include all nested commands in the output.',
    }),
};
Help.strict = false;
Help.tag = command_tags_enum_1.default.SUPPORT;
exports.default = Help;
