"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const authenticate_user_1 = require("../../utils/authenticate-user");
const get_info_table_1 = require("../../utils/tables/get-info-table");
const base_command_1 = require("../base-command");
class VarInfo extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async run() {
        if (!process.env.LIBLAB_DEBUG) {
            this.error('Invalid command');
        }
        const currentUser = await (0, authenticate_user_1.authenticateUser)({ liblabClientProvider: this.liblabClient });
        this.log('\nEnvironment and CLI variables:\n');
        const table = (0, get_info_table_1.getInfoTable)(currentUser);
        this.log(table.render());
        return this.log('\n');
    }
}
VarInfo.description = 'View environment and CLI variable info.';
VarInfo.examples = ['liblab info'];
// hide the command from help
VarInfo.hidden = true;
VarInfo.tag = command_tags_enum_1.default.SUPPORT;
exports.default = VarInfo;
