"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const analytics_provider_1 = tslib_1.__importDefault(require("../../lib/analytics-provider"));
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const cmds_json_1 = require("../../logs/cmds.json");
const get_limited_console_error_1 = tslib_1.__importDefault(require("../../utils/get-limited-console-error"));
const base_command_1 = require("../base-command");
const emailRegex = /\${email}/g;
class Login extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    constructDyamicLog() {
        var _a;
        return cmds_json_1.LOGIN.SUCCESS.replaceAll(emailRegex, (_a = this.liblabClient.currentUser) === null || _a === void 0 ? void 0 : _a.email);
    }
    async run() {
        try {
            await this.liblabClient.init();
            await this.liblabClient.login();
            const dynamicLog = this.constructDyamicLog();
            this.log(dynamicLog);
            if (!this.liblabClient.currentUser) {
                return;
            }
            this.analytics = new analytics_provider_1.default({
                commandParams: { argv: this.argv, config: this.config, name: 'command login' },
                commandType: Login,
                currentUser: this.liblabClient.currentUser,
            });
            await this.analytics.logEvent({ status: 'succeed' });
        }
        catch (error) {
            const msg = (0, get_limited_console_error_1.default)(error.message || cmds_json_1.LOGIN.DEFAULT_ERROR);
            this.log(msg);
            this.analytics = new analytics_provider_1.default({
                commandParams: { argv: this.argv, config: this.config, name: 'command login' },
                commandType: Login,
                currentUser: this.liblabClient.currentUser,
            });
            await this.analytics.logEvent({ reason: msg, status: 'failed' });
        }
    }
}
Login.description = 'Log-in or register a user in liblab';
Login.examples = ['liblab login'];
Login.tag = command_tags_enum_1.default.AUTH;
exports.default = Login;
