"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const cmds_json_1 = require("../../logs/cmds.json");
const get_limited_console_error_1 = tslib_1.__importDefault(require("../../utils/get-limited-console-error"));
const base_command_1 = require("../base-command");
class Logout extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async run() {
        try {
            await this.liblabClient.init();
            if (!this.liblabClient.currentUser) {
                throw new Error(cmds_json_1.LOGOUT.NOT_LOGGED_IN_YET);
            }
            await this.liblabClient.logout();
            this.log(cmds_json_1.LOGOUT.SUCCESS);
        }
        catch (error) {
            this.log((0, get_limited_console_error_1.default)(error.message || cmds_json_1.LOGOUT.DEFAULT_ERROR));
        }
    }
}
Logout.description = 'Log-out the current user';
Logout.examples = ['liblab logout'];
Logout.tag = command_tags_enum_1.default.AUTH;
exports.default = Logout;
