"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const analytics_provider_1 = tslib_1.__importDefault(require("../../lib/analytics-provider"));
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const authenticate_user_1 = require("../../utils/authenticate-user");
const get_token_table_1 = require("../../utils/tables/get-token-table");
const base_command_1 = require("../base-command");
class TokenList extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async catch(error) {
        const reason = error.message;
        const logEventParams = {
            error,
            reason,
            status: 'failed',
        };
        await super.catch(error, logEventParams);
    }
    async run() {
        const currentUser = await (0, authenticate_user_1.authenticateUser)({ liblabClientProvider: this.liblabClient });
        this.analytics = new analytics_provider_1.default({
            commandParams: { argv: this.argv, config: this.config, name: 'command token:list' },
            commandType: TokenList,
            currentUser,
        });
        const tokens = await this.liblabClient.listLongLivedTokens();
        this.log('Here are all of your active tokens:');
        const tokensTable = (0, get_token_table_1.getTokensTable)(tokens);
        this.log(tokensTable.render());
        await this.analytics.logEvent({
            status: 'succeed',
        });
    }
}
TokenList.description = 'List all available tokens for the current environment';
TokenList.examples = ['liblab token list'];
TokenList.tag = command_tags_enum_1.default.AUTH;
exports.default = TokenList;
