"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_tags_enum_1 = tslib_1.__importDefault(require("../../enums/command-tags.enum"));
const analytics_provider_1 = tslib_1.__importDefault(require("../../lib/analytics-provider"));
const liblab_1 = require("../../lib/liblab");
const liblab_client_provider_1 = tslib_1.__importDefault(require("../../lib/liblab-client-provider"));
const authenticate_user_1 = require("../../utils/authenticate-user");
const base_command_1 = require("../base-command");
class TokenRevoke extends base_command_1.BaseCommand {
    constructor(argv, config) {
        super(argv, config);
        this.liblabClient = new liblab_client_provider_1.default(config);
    }
    async catch(error) {
        const errorMessage = error.message || 'Unable to revoke token';
        const logEventParams = {
            error,
            reason: errorMessage,
            status: 'failed',
        };
        await super.catch(error, logEventParams);
    }
    async run() {
        const currentUser = await (0, authenticate_user_1.authenticateUser)({ liblabClientProvider: this.liblabClient });
        this.analytics = new analytics_provider_1.default({
            commandParams: { argv: this.argv, config: this.config, name: 'command token:revoke' },
            commandType: TokenRevoke,
            currentUser,
        });
        const { args } = await this.parse(TokenRevoke);
        await (0, liblab_1.revokeLongLivedToken)(args.token_name);
        this.log(`Token revoked successfully`);
        await this.analytics.logEvent({ status: 'succeed' });
        return true;
    }
}
TokenRevoke.args = {
    token_name: core_1.Args.string({
        required: true,
    }),
};
TokenRevoke.description = 'Revokes permission for a given token';
TokenRevoke.examples = ['liblab token revoke TOKEN_NAME'];
TokenRevoke.tag = command_tags_enum_1.default.AUTH;
exports.default = TokenRevoke;
