"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const semver_1 = tslib_1.__importDefault(require("semver"));
const paths_default_1 = require("../../constants/paths.default");
const npm_1 = tslib_1.__importDefault(require("../../lib/npm"));
const brewUpdateMsg = 'brew upgrade liblab';
const npmUpdateMsg = 'npm update -g liblab';
const useNPXMessage = `Tired of seeing this message? Run:
  npx liblab@latest <command>
  to always use the latest version of liblab.`;
const initLocalTempDirectory = async (error) => {
    try {
        await (0, fs_extra_1.ensureDir)(paths_default_1.tempDirectory);
    }
    catch {
        error('Failed to init local directories');
    }
};
const getPackageManagerUpdateMessage = (thisVersion, latestVersion) => {
    // oclif compiles ts to common js
    // eslint-disable-next-line unicorn/prefer-module
    const isNpm = !__dirname.includes('homebrew');
    const updateMessage = isNpm ? npmUpdateMsg : brewUpdateMsg;
    const baseMessage = `Update available ${thisVersion} → ${latestVersion} Run:`;
    const msg = [baseMessage, updateMessage];
    if (isNpm) {
        msg.push(useNPXMessage);
    }
    return msg.join('\n');
};
const verifyLatestVersion = async ({ config, error, warn, }) => {
    await initLocalTempDirectory(error);
    const latestVersion = await (0, npm_1.default)('liblab');
    if (!latestVersion) {
        warn('Unable to connect to connect to NPM. It is possible your version is out-of-date.');
    }
    const thisVersion = config.version;
    const environment = process.env.LIBLAB_ENVIRONMENT || 'production';
    const isInValidVersion = !process.env.LIBLAB_ALLOW_OLD_VERSION &&
        semver_1.default.gt(latestVersion, thisVersion) &&
        environment === 'production';
    if (!isInValidVersion) {
        return;
    }
    const errorMessage = getPackageManagerUpdateMessage(thisVersion, latestVersion);
    error(errorMessage);
};
const hook = async function () {
    await initLocalTempDirectory(this.error);
    await verifyLatestVersion({ config: this.config, error: this.error, warn: this.warn });
};
exports.default = hook;
