"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Auth0Client = void 0;
const tslib_1 = require("tslib");
const openid_client_1 = require("openid-client");
const env_1 = tslib_1.__importDefault(require("../constants/env"));
const { auth0ClientId, auth0Issuer, auth0audience } = env_1.default;
const GRANT_TYPE = 'urn:ietf:params:oauth:grant-type:device_code';
const SCOPES = 'openid email';
const ONE_DAY_IN_MILLISECONDS = 24 * 3600 * 1000;
class Auth0 {
    constructor(client) {
        this.client = client;
    }
    static async getInstance({ max_age = ONE_DAY_IN_MILLISECONDS, } = {}) {
        const issuer = await openid_client_1.Issuer.discover(auth0Issuer);
        const myClient = new issuer.Client({
            client_id: auth0ClientId,
            grant_types: [GRANT_TYPE],
            max_age,
            token_endpoint_auth_method: 'none',
        });
        return new Auth0(myClient);
    }
    async deviceAuthorization() {
        return this.client.deviceAuthorization({
            audience: auth0audience,
            scope: SCOPES,
        });
    }
    async revokeToken(token) {
        await this.client.revoke(token);
        return true;
    }
}
exports.Auth0Client = Auth0.getInstance;
