"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.exists = exists;
exports.rm = rm;
exports.unzip = unzip;
exports.unzipEntry = unzipEntry;
exports.createZip = createZip;
exports.identifyStringType = identifyStringType;
exports.isEmpty = isEmpty;
exports.copyAndRemove = copyAndRemove;
exports.copyRecursiveSync = copyRecursiveSync;
const tslib_1 = require("tslib");
const adm_zip_1 = tslib_1.__importDefault(require("adm-zip"));
const node_fs_1 = tslib_1.__importDefault(require("node:fs"));
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const rimraf_1 = require("rimraf");
const helpers_1 = require("./helpers");
function exists(path) {
    try {
        return node_fs_1.default.existsSync(path);
    }
    catch {
        return false;
    }
}
function rm(path) {
    try {
        node_fs_1.default.rmSync(path, { recursive: true });
    }
    catch {
        return false;
    }
    return true;
}
const setFileDate = (filePath, dateToUpdate = new Date()) => {
    node_fs_1.default.utimesSync(filePath, dateToUpdate, dateToUpdate);
};
function unzip({ outputPath, zipBuffer, zipPath, }) {
    try {
        const zip = new adm_zip_1.default(zipPath || zipBuffer);
        zip.extractAllTo(outputPath, true);
        zip.getEntries().forEach(({ entryName }) => setFileDate(node_path_1.default.join(outputPath, entryName)));
    }
    catch (error) {
        (0, helpers_1.debugLog)(`Failed to extract zip from: ${zipPath}, to ${outputPath}, msg: ${error.message}`, error);
        throw new Error('Failed to extract zip');
    }
}
function unzipEntry(zipBuffer, entryPath, outputPath, maintainEntryPath = true) {
    try {
        const zip = new adm_zip_1.default(zipBuffer);
        zip.extractEntryTo(entryPath, outputPath, maintainEntryPath, true);
        setFileDate(outputPath);
    }
    catch (error) {
        (0, helpers_1.debugLog)(`Failed to extract zip entry ${entryPath} to ${outputPath}, msg: ${error.message}`, error);
        throw new Error('Failed to extract zip');
    }
}
async function createZip(inPath, outPath) {
    try {
        const zip = new adm_zip_1.default();
        // Take the contents of the inPath and add them to the zip
        await zip.addLocalFolderPromise(inPath, {});
        // Write the zip to the outPath
        await zip.writeZipPromise(outPath);
    }
    catch {
        throw new Error('Failed to create zip files from hooks');
    }
}
function identifyStringType(input) {
    try {
        // eslint-disable-next-line no-new
        new URL(input);
        return 'URL';
    }
    catch {
        // If it's not a URL, let's check if it's an absolute or relative path
        if (node_path_1.default.isAbsolute(input)) {
            return 'Absolute Path';
        }
        if (input.startsWith('~')) {
            return 'Tilde Path';
        }
        return 'Relative Path';
    }
}
function isEmpty(folderPath) {
    const files = node_fs_1.default.readdirSync(folderPath);
    return files.length === 0;
}
async function copyAndRemove(source, destination, pathToRemove) {
    try {
        copyRecursiveSync(source, destination);
        await (0, rimraf_1.rimraf)(pathToRemove || source);
    }
    catch (error) {
        (0, helpers_1.debugLog)(`failed to copy and remove. Source: ${source}. Destination ${destination}. Path to remove: ${pathToRemove || source}. msg: ${error.message}`, error);
        throw new Error('failed to copy and remove');
    }
}
function copyRecursiveSync(source, destination) {
    const stat = node_fs_1.default.statSync(source);
    if (stat.isDirectory()) {
        if (!node_fs_1.default.existsSync(destination)) {
            node_fs_1.default.mkdirSync(destination, { recursive: true });
        }
        for (const entry of node_fs_1.default.readdirSync(source)) {
            const srcPath = node_path_1.default.join(source, entry);
            const destPath = node_path_1.default.join(destination, entry);
            copyRecursiveSync(srcPath, destPath);
        }
    }
    else {
        node_fs_1.default.copyFileSync(source, destination);
    }
}
