"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BitbucketClient = void 0;
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const cmds_json_1 = require("../../logs/cmds.json");
const rethrown_error_1 = require("../../utils/error/rethrown-error");
const helpers_1 = require("../helpers");
const git_client_1 = require("./git-client");
class BitbucketClient extends git_client_1.GitClient {
    async clone(repoUrl) {
        return super.clone(repoUrl, { username: 'x-token-auth' });
    }
    async createPullRequest({ body, branchName, repo, targetBranch, title, }) {
        try {
            const url = `https://api.bitbucket.org/2.0/repositories/${this.owner}/${repo}/pullrequests`;
            const response = await axios_1.default.post(url, {
                title,
                description: body,
                source: {
                    branch: {
                        name: branchName,
                    },
                },
                destination: {
                    branch: {
                        name: targetBranch,
                    },
                },
            }, {
                headers: {
                    Accept: 'application/json',
                    Authorization: `Bearer ${this.token}`,
                    'Content-Type': 'application/json',
                },
            });
            return {
                html_url: response.data.links.html.href,
            };
        }
        catch (error) {
            (0, helpers_1.debugLog)('Failed to create pull request', error);
            throw new rethrown_error_1.RethrownError(cmds_json_1.PR.ERROR.FAILED_TO_CREATE_PULL_REQUEST, error);
        }
    }
    formatRepoUrl(owner, repo) {
        return `https://bitbucket.org/${owner}/${repo}.git`;
    }
    async getAuthenticatedUser() {
        // No need to get authenticated user for Bitbucket since there is no user
    }
    getCommitAuthor() {
        return {
            email: `bot@liblab.com`,
            name: 'liblab',
        };
    }
    async push(branch) {
        return super.push(branch, { username: 'x-token-auth' });
    }
    async setupAuthenticatedUser() {
        // No need to setup authenticated user for Bitbucket since there is no user
    }
}
exports.BitbucketClient = BitbucketClient;
