"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubClient = void 0;
const rest_1 = require("@octokit/rest");
const cmds_json_1 = require("../../logs/cmds.json");
const rethrown_error_1 = require("../../utils/error/rethrown-error");
const git_platform_token_1 = require("../../utils/git-platform-token");
const helpers_1 = require("../helpers");
const git_client_1 = require("./git-client");
class GitHubClient extends git_client_1.GitClient {
    constructor(owner, token) {
        super(owner, token);
        this.octokit = new rest_1.Octokit({ auth: token });
        (0, git_platform_token_1.warnAboutLegacyGithubToken)();
    }
    async createPullRequest({ body, branchName, repo, targetBranch, title, }) {
        try {
            const { data } = await this.octokit.pulls.create({
                base: targetBranch,
                body,
                head: branchName,
                owner: this.owner,
                repo,
                title,
            });
            return data;
        }
        catch (error) {
            (0, helpers_1.debugLog)('Failed to create pull request', error);
            throw new rethrown_error_1.RethrownError(cmds_json_1.PR.ERROR.FAILED_TO_CREATE_PULL_REQUEST, error);
        }
    }
    formatRepoUrl(owner, repo) {
        return `https://github.com/${owner}/${repo}.git`;
    }
    getCommitAuthor() {
        try {
            return {
                email: `${this.authenticatedUser.id}+${this.authenticatedUser.login}@users.noreply.github.com`,
                name: this.owner,
            };
        }
        catch (error) {
            (0, helpers_1.debugLog)('Failed to get commit author', error);
            throw new rethrown_error_1.RethrownError(cmds_json_1.PR.ERROR.FAILED_TO_GET_AUTHOR, error);
        }
    }
    async setupAuthenticatedUser() {
        this.authenticatedUser = await this.getAuthenticatedUser();
    }
    async getAuthenticatedUser() {
        try {
            const { data } = await this.octokit.users.getAuthenticated();
            return data;
        }
        catch (error) {
            throw new rethrown_error_1.RethrownError(cmds_json_1.PR.ERROR.GITHUB_AUTH_ERROR, error);
        }
    }
}
exports.GitHubClient = GitHubClient;
