"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.client = void 0;
exports.createLongLivedToken = createLongLivedToken;
exports.revokeLongLivedToken = revokeLongLivedToken;
exports.changePassword = changePassword;
const sdk_1 = require("@liblab/sdk");
const json_utils_1 = require("../utils/json.utils");
const helpers_1 = require("./helpers");
const ONE_DAY_IN_MILLISECONDS = 24 * 3600 * 1000;
// share client between liblab-client provider and this file until further refactor
exports.client = new sdk_1.Liblab({});
async function createLongLivedToken(name, durationInDays = 365, scope = [
    'SDK',
    'API',
    'BUILD',
    'ORG',
    'ARTIFACT',
    'DOC',
]) {
    const payload = {
        expiresAt: new Date(Date.now() + durationInDays * ONE_DAY_IN_MILLISECONDS).toISOString(),
        name,
        scope,
    };
    let response;
    try {
        response = await exports.client.token.createToken(payload);
    }
    catch (error) {
        throw new Error((0, json_utils_1.messageFromLiblabSdkError)(error));
    }
    return response.token;
}
async function revokeLongLivedToken(name) {
    let tokenToRevoke;
    try {
        const currentUser = await exports.client.user.getCurrentUser();
        const tokens = await exports.client.token.findTokensByUserId(currentUser.id);
        tokenToRevoke = tokens.find((token) => token.name === name);
    }
    catch (error) {
        throw new Error((0, json_utils_1.messageFromLiblabSdkError)(error));
    }
    if (!tokenToRevoke) {
        throw new Error(`Token with name ${name} not found for the current user`);
    }
    await exports.client.token.removeToken(tokenToRevoke.id);
    return true;
}
async function changePassword() {
    try {
        const response = await exports.client.auth0.resetPasswordAuth0();
        return response;
    }
    catch (error) {
        (0, helpers_1.debugLog)('/lib/liblab#auth0.resetPasswordAuth0', error);
        return null;
    }
}
