"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.authenticationSchema = exports.oauthCustomizationSchema = exports.customCustomizationSchema = exports.basicCustomizationSchema = exports.apiKeyCustomizationSchema = exports.accessCustomizationSchema = void 0;
const zod_1 = require("zod");
exports.accessCustomizationSchema = zod_1.z
    .object({
    prefix: zod_1.z
        .string()
        .describe('The prefix to use for the access authentication')
        .default('Bearer'),
})
    .optional();
exports.apiKeyCustomizationSchema = zod_1.z
    .object({
    header: zod_1.z
        .string()
        .describe('The header to use for the api key authentication')
        .default('X-API-KEY'),
})
    .optional();
exports.basicCustomizationSchema = zod_1.z
    .object({
    enabled: zod_1.z.boolean().default(true),
})
    .optional();
exports.customCustomizationSchema = zod_1.z
    .object({
    prefix: zod_1.z
        .string()
        .describe('The prefix to use for the custom authentication')
        .default('')
        .optional(),
})
    .optional();
exports.oauthCustomizationSchema = zod_1.z
    .object({
    enabled: zod_1.z.boolean().default(true).describe('Enable oauth authentication'),
    basic: zod_1.z
        .boolean()
        .default(false)
        .describe('Use basic authentication header for the oauth token'),
    tokenEndpoint: zod_1.z
        .object({
        path: zod_1.z
            .string()
            .describe('The path to use for the oauth token endpoint. This is used to retrieve the oauth token from the server'),
        method: zod_1.z
            .enum(['get', 'post'])
            .default('post')
            .describe('The method to use for the oauth token endpoint'),
        definition: zod_1.z.object({}).passthrough().describe('The definition of the token endpoint'),
    })
        .strict()
        .optional(),
    securityScheme: zod_1.z
        .object({
        name: zod_1.z.string().describe('The name of the security scheme for the oauth'),
        definition: zod_1.z
            .object({})
            .passthrough()
            .describe('The security scheme definition for the oauth.'),
    })
        .strict()
        .optional()
        .describe('The security scheme definition for the oauth'),
})
    .optional();
exports.authenticationSchema = zod_1.z
    .object({
    access: exports.accessCustomizationSchema,
    apiKey: exports.apiKeyCustomizationSchema,
    basic: exports.basicCustomizationSchema,
    custom: exports.customCustomizationSchema,
    oauth: exports.oauthCustomizationSchema,
})
    .optional();
