"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.endpointCustomizationSchema = exports.openApiPathSchema = exports.OasEndpointSchema = exports.methodSchema = exports.liblabPaginationSchema = exports.liblabPaginationInputFieldSchema = void 0;
const zod_1 = require("zod");
exports.liblabPaginationInputFieldSchema = zod_1.z.object({
    name: zod_1.z.string(),
    in: zod_1.z.literal('query'),
    type: zod_1.z.union([zod_1.z.literal('limit'), zod_1.z.literal('offset')]),
});
exports.liblabPaginationSchema = zod_1.z.object({
    type: zod_1.z.literal('limitOffset'),
    inputFields: zod_1.z.array(exports.liblabPaginationInputFieldSchema),
    resultsArray: zod_1.z.object({
        results: zod_1.z.string(),
        defaultPageSize: zod_1.z.number(),
    }),
});
exports.methodSchema = zod_1.z.object({
    operationId: zod_1.z.string().optional(),
    streaming: zod_1.z.boolean().optional(),
    scopes: zod_1.z.record(zod_1.z.array(zod_1.z.string())).optional(),
    pagination: exports.liblabPaginationSchema.optional(),
});
exports.OasEndpointSchema = zod_1.z
    .object({
    get: exports.methodSchema.optional(),
    post: exports.methodSchema.optional(),
    put: exports.methodSchema.optional(),
    delete: exports.methodSchema.optional(),
    patch: exports.methodSchema.optional(),
    // Add other HTTP methods if needed
})
    .nonstrict(); // Allows additional properties if necessary
exports.openApiPathSchema = zod_1.z.record(zod_1.z.string(), exports.OasEndpointSchema).optional();
exports.endpointCustomizationSchema = zod_1.z
    .union([exports.openApiPathSchema, zod_1.z.string().regex(/^[\w./\\-]+$/), zod_1.z.string().url()])
    .describe('Customizations for specific endpoints');
