"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrySchema = void 0;
const zod_1 = require("zod");
exports.retrySchema = zod_1.z
    .object({
    backOffFactor: zod_1.z
        .number()
        .positive()
        .describe('What is the exponent base used to calulate wait times?')
        .optional(),
    enabled: zod_1.z.boolean().describe('Should the SDKs include retry behavior?').optional(),
    httpCodesToRetry: zod_1.z
        .array(zod_1.z.number().int().min(200).max(599))
        .describe('What HTTP codes should the SDKs retry on?')
        .optional(),
    httpMethodsToRetry: zod_1.z
        .array(zod_1.z.enum(['GET', 'POST', 'PUT', 'DELETE', 'PATCH', 'HEAD', 'OPTIONS', 'CONNECT', 'TRACE']))
        .describe('What HTTP methods should the SDKs retry on?')
        .optional(),
    maxAttempts: zod_1.z
        .number()
        .describe('How many attempts should the SDKs make before giving up?')
        .optional(),
    maxDelay: zod_1.z
        .number()
        .nonnegative()
        .describe('What is the maximum time between attempts in milliseconds?')
        .optional(),
    retryDelay: zod_1.z
        .number()
        .describe('How long should the SDKs wait between attempts in milliseconds?'),
    retryDelayJitter: zod_1.z
        .number()
        .nonnegative()
        .describe('What is the maximum random jitter applied to wait times in milliseconds?')
        .optional(),
})
    .describe('Retry functionality customization')
    .optional();
