"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readmeSchema = exports.buildAllModelsSchema = exports.DEFAULT_BUILD_ALL_MODELS = exports.responseHeadersSchema = exports.DEFAULT_RESPONSE_HEADERS = exports.refreshTokenParamsSchema = exports.licenseSchema = exports.includeOptionalSnippetParametersSchema = exports.DEFAULT_INCLUDE_OPTIONAL_SNIPPET_PARAMETERS = exports.hookDependenciesSchema = exports.hookDependency = exports.generateEnvSchema = exports.DEFAULT_GENERATE_ENV = exports.environmentsSchema = exports.environmentVariablesSchema = exports.environmentVariable = exports.documentationSchema = exports.devContainerSchema = exports.DEFAULT_DEV_CONTAINER = exports.enhancedSpecDocumentationOptionsSchema = void 0;
const zod_1 = require("zod");
const snippets_schema_1 = require("../../../schemas/customizations/documentation/snippets.schema");
exports.enhancedSpecDocumentationOptionsSchema = zod_1.z.object({
    customOutputName: zod_1.z
        .string()
        .describe('Name of the output file, will default to enhancedApiSpec.json')
        .optional()
        .refine((name) => !name || name.endsWith('.json') || name.endsWith('.yaml') || name.endsWith('.yml'), {
        message: 'customOutputName must end with .json, .yaml, or .yml',
    }),
});
exports.DEFAULT_DEV_CONTAINER = true;
exports.devContainerSchema = zod_1.z
    .boolean()
    .describe('Should example dev container files be generated?')
    .default(exports.DEFAULT_DEV_CONTAINER);
exports.documentationSchema = zod_1.z
    .object({
    snippets: snippets_schema_1.snippetsSchema,
    enhancedApiSpec: exports.enhancedSpecDocumentationOptionsSchema.optional(),
})
    .optional();
exports.environmentVariable = zod_1.z
    .object({
    description: zod_1.z.string().describe('A description of the environment variable'),
    name: zod_1.z.string().describe('The name of the environment variable'),
})
    .strict()
    .describe('An environment variable');
exports.environmentVariablesSchema = exports.environmentVariable.array().optional();
exports.environmentsSchema = zod_1.z
    .array(zod_1.z
    .object({
    name: zod_1.z.string().describe('The name of the environment'),
    url: zod_1.z.string().describe('The URL of the environment').url(),
})
    .strict()
    .describe('A deployment environment'))
    .optional();
exports.DEFAULT_GENERATE_ENV = true;
exports.generateEnvSchema = zod_1.z
    .boolean()
    .describe('Should example .env files be generated?')
    .default(exports.DEFAULT_GENERATE_ENV);
exports.hookDependency = zod_1.z
    .object({
    groupId: zod_1.z.string().describe('The groupId of the hook dependency').optional(),
    name: zod_1.z.string().describe('The name of the hook dependency'),
    version: zod_1.z.string().describe('The version of the hook dependency'),
})
    .strict()
    .describe('A dependency that should be installed for the hook');
exports.hookDependenciesSchema = exports.hookDependency.array().optional();
exports.DEFAULT_INCLUDE_OPTIONAL_SNIPPET_PARAMETERS = true;
exports.includeOptionalSnippetParametersSchema = zod_1.z
    .boolean()
    .describe('toggles whether optional parameters are included in code snippets in generated SDK documentation.')
    .default(exports.DEFAULT_INCLUDE_OPTIONAL_SNIPPET_PARAMETERS);
exports.licenseSchema = zod_1.z
    .object({
    type: zod_1.z
        .enum(['MIT', 'GPL3', 'APACHE', 'NONE', 'CUSTOM'])
        .describe('What license should the SDKs be covered under?')
        .default('NONE'),
    url: zod_1.z.string().trim().url().describe('URL for a CUSTOM license').optional(),
})
    .strict()
    .describe('Optional configuration for licensing the SDKs')
    .optional()
    .refine((data) => (data === null || data === void 0 ? void 0 : data.type) !== 'CUSTOM' || Boolean(data.url), {
    message: 'License "CUSTOM" requires an url',
});
exports.refreshTokenParamsSchema = zod_1.z
    .object({
    bearerKey: zod_1.z.string().describe('The key to use for the bearer token'),
    endpoint: zod_1.z.string().describe('The endpoint to use for refreshing the token'),
    refreshKey: zod_1.z.string().describe('The key to use for the refresh token'),
})
    .strict()
    .describe('The parameters for the refresh token system')
    .optional();
exports.DEFAULT_RESPONSE_HEADERS = false;
exports.responseHeadersSchema = zod_1.z
    .boolean()
    .describe('Should the SDKs return a response with both the data and headers?')
    .default(exports.DEFAULT_RESPONSE_HEADERS);
exports.DEFAULT_BUILD_ALL_MODELS = false;
exports.buildAllModelsSchema = zod_1.z
    .boolean()
    .describe('Should unreferenced models be built?')
    .default(exports.DEFAULT_BUILD_ALL_MODELS);
exports.readmeSchema = zod_1.z
    .object({
    apiDescription: zod_1.z.string().describe('Overwrites the SDK README description').optional(),
})
    .optional();
