"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.integrationsSchema = exports.enhancedApiSpecIntegrationSchema = exports.mintlifyIntegrationSchema = exports.readmeIOIntegrationSchema = exports.redoclyIntegrationSchema = exports.ApiDocumentationProvider = void 0;
const zod_1 = require("zod");
var ApiDocumentationProvider;
(function (ApiDocumentationProvider) {
    ApiDocumentationProvider["Mintlify"] = "mintlify";
    ApiDocumentationProvider["Readme"] = "readmeIO";
    ApiDocumentationProvider["Redocly"] = "redocly";
})(ApiDocumentationProvider || (exports.ApiDocumentationProvider = ApiDocumentationProvider = {}));
exports.redoclyIntegrationSchema = zod_1.z.object({
    openapiPath: zod_1.z.string().optional(),
});
exports.readmeIOIntegrationSchema = zod_1.z.object({
    openapiPath: zod_1.z.string().optional(),
});
exports.mintlifyIntegrationSchema = zod_1.z.object({
    codeSamplesLanguages: zod_1.z
        .array(zod_1.z.string())
        .describe('Selecting the languages to enhance and include in the mintlify integration. The selected languages will override the languages shown in the mintlify UI.')
        .optional()
        .refine((val) => val && new Set(val).size === val.length, {
        message: 'codeSamplesLanguages must contain unique values',
    }),
});
exports.enhancedApiSpecIntegrationSchema = zod_1.z
    .object({
    githubRepoName: zod_1.z.string(),
    targetBranch: zod_1.z
        .string()
        .describe('The target to branch off from when opening a PR')
        .default('main'),
    provider: zod_1.z
        .enum(['mintlify', 'redocly', 'readmeIO'])
        .describe('Selecting the provider will enable the liblab service to generate the required files for your integration provider'),
    redocly: exports.redoclyIntegrationSchema,
    readmeIO: exports.readmeIOIntegrationSchema,
    mintlify: exports.mintlifyIntegrationSchema,
})
    .describe('API documentation integration object')
    .optional();
exports.integrationsSchema = zod_1.z.object({
    enhancedApiSpec: exports.enhancedApiSpecIntegrationSchema.optional(),
});
