"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.integrationsSchema = exports.enhancedApiSpecIntegrationSchema = exports.ApiDocumentationProvider = exports.targetBranchSchema = exports.githubRepoNameSchema = void 0;
const zod_1 = require("zod");
exports.githubRepoNameSchema = zod_1.z
    .string()
    .describe('The name of the Github Repo that will be Pull Requested to');
exports.targetBranchSchema = zod_1.z
    .string()
    .min(2)
    .describe('The target to branch off from when opening a PR, if not specified will default to main branch')
    .optional();
var ApiDocumentationProvider;
(function (ApiDocumentationProvider) {
    ApiDocumentationProvider["Mintlify"] = "mintlify";
    ApiDocumentationProvider["Readme"] = "readmeIO";
    ApiDocumentationProvider["Redocly"] = "redocly";
})(ApiDocumentationProvider || (exports.ApiDocumentationProvider = ApiDocumentationProvider = {}));
exports.enhancedApiSpecIntegrationSchema = zod_1.z
    .object({
    githubRepoName: exports.githubRepoNameSchema,
    targetBranch: exports.targetBranchSchema.optional().default('main'),
    provider: zod_1.z
        .enum([
        ApiDocumentationProvider.Mintlify,
        ApiDocumentationProvider.Redocly,
        ApiDocumentationProvider.Readme,
    ])
        .describe('Selecting the provider will enable the liblab service to generate the required files for your integration provider'),
    redocly: zod_1.z
        .object({
        openapiPath: zod_1.z.string().optional(),
    })
        .optional(),
    readmeIO: zod_1.z
        .object({
        openapiPath: zod_1.z.string().optional(),
    })
        .optional(),
    mintlify: zod_1.z
        .object({
        codeSamplesLanguages: zod_1.z
            .array(zod_1.z.string())
            .describe('Selecting the languages to enhance and include in the mintlify integration. The selected languages will override the languages shown in the mintlify UI.')
            .optional()
            .refine((val) => {
            if (!val) {
                return true;
            }
            return new Set(val).size === val.length;
        }, {
            message: 'codeSamplesLanguages must contain unique values',
        }),
    })
        .optional(),
})
    .describe('API documentation integration object');
exports.integrationsSchema = zod_1.z
    .object({
    enhancedApiSpec: exports.enhancedApiSpecIntegrationSchema.optional(),
})
    .optional();
