"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.targetBranchSchema = exports.renameIllegalModelPropertiesSchema = exports.ignoreSchema = exports.hookDependenciesSchema = exports.hookDependency = exports.homepageSchema = exports.githubRepoNameSchema = exports.authorsSchema = exports.additionalConstructorParametersSchema = exports.additionalConstructorParameterSchema = void 0;
const zod_1 = require("zod");
const utils_1 = require("../utils");
exports.additionalConstructorParameterSchema = zod_1.z
    .object({
    name: zod_1.z.string().describe('The name of the variable'),
    example: zod_1.z.string().describe('An example value for the variable').optional(),
})
    .strict()
    .describe('An additional variable to be included in the constructor');
exports.additionalConstructorParametersSchema = exports.additionalConstructorParameterSchema
    .array()
    .refine((data) => (0, utils_1.hasDuplicates)(data.map((v) => v.name)), {
    message: 'The additional variables must have unique names',
})
    .describe('Additional variables to include in the constructor and access in the hooks')
    .optional();
exports.authorsSchema = zod_1.z
    .object({
    email: zod_1.z.string().email().default('').optional(),
    name: zod_1.z.string(),
})
    .strict()
    .array()
    .describe('The list of authors who contribute to the SDK (In TypeScript the first is the only one displayed)')
    .optional();
exports.githubRepoNameSchema = zod_1.z
    .string()
    .describe('The name of the Github Repo that will be Pull Requested to')
    .optional();
exports.homepageSchema = zod_1.z.string().url().optional();
exports.hookDependency = zod_1.z
    .object({
    groupId: zod_1.z.string().describe('The groupId of the hook dependency').optional(),
    name: zod_1.z.string().describe('The name of the hook dependency'),
    version: zod_1.z.string().describe('The version of the hook dependency'),
})
    .strict()
    .describe('A dependency that should be installed for the hook');
exports.hookDependenciesSchema = exports.hookDependency.array().optional();
exports.ignoreSchema = zod_1.z
    .array(zod_1.z.string().describe('A file path that should be ignored'))
    .describe("List of files that shouldn't be produced by liblab, used for when you want to keep specific files safe from changes")
    .default([]);
exports.renameIllegalModelPropertiesSchema = zod_1.z
    .boolean()
    .describe('renames all model properties with illegal names, during the SDK generation')
    .default(true);
exports.targetBranchSchema = zod_1.z
    .string()
    .min(2)
    .describe('The target to branch off from when opening a PR, if not specified will default to main branch')
    .optional();
