"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.liblabConfigV2InputSchema = void 0;
const zod_1 = require("zod");
const mcp_schema_1 = require("../../schemas/mcp/mcp.schema");
const customizations_schema_1 = require("./customizations/customizations-schema");
const integrations_1 = require("./integrations");
const language_options_schema_1 = require("./language-options/language-options.schema");
const languages_1 = require("./languages");
const schemas_1 = require("./schemas");
/**
 * The base schema for the LibLab configuration file.
 * This schema must be declared first to prevent circular dependencies between the schema,
 * its transformations, defaults, and refinements.
 *
 * The schema defines the core structure and validation rules for the config,
 * while transformations (like setDefaultLanguageOptions), defaults, and refinements
 * (like refineAuthenticationCustomizations) build upon and modify this base schema.
 *
 * By declaring the base schema first, we ensure that these dependent operations
 * can safely reference and extend the schema without creating circular dependencies.
 */
exports.liblabConfigV2InputSchema = zod_1.z
    .object({
    liblabConfigVersion: zod_1.z.string().default('1.0.0'),
    sdkName: schemas_1.sdkNameSchema,
    sdkVersion: schemas_1.sdkVersionSchema,
    apiVersion: schemas_1.apiVersionSchema,
    apiName: schemas_1.apiNameSchema,
    customizations: customizations_schema_1.customizationsSchema,
    specFilePath: schemas_1.specFilePathSchema,
    languages: languages_1.languagesSchema,
    createDocs: schemas_1.createDocsSchema,
    docs: schemas_1.docsSchema,
    auth: schemas_1.authSchema,
    baseUrl: schemas_1.baseUrlSchema,
    languageOptions: language_options_schema_1.languageOptionsSchema,
    liblabVersion: schemas_1.liblabVersionSchema,
    validationsToIgnore: schemas_1.validationsToIgnoreSchema,
    publishing: schemas_1.publishingSchema,
    workflows: schemas_1.workflowsSchema,
    integrations: integrations_1.integrationsSchema,
    analytics: schemas_1.analyticsSchema,
    mcp: mcp_schema_1.mcpSchema,
})
    .describe('The liblab Configuration File');
