"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.analyticsSchema = exports.workflowsSchema = exports.publishingSchema = exports.publishingPlatformSchema = exports.docsSchema = exports.docsOptionsSchema = exports.DocsOptions = exports.liblabVersionSchema = exports.validationsToIgnoreSchema = exports.baseUrlSchema = exports.authSchema = exports.createDocsSchema = exports.specFilePathSchema = exports.apiNameSchema = exports.apiVersionSchema = exports.sdkVersionSchema = exports.sdkNameSchema = void 0;
const semver_1 = require("semver");
const zod_1 = require("zod");
const languages_1 = require("./languages");
const utils_1 = require("./utils");
exports.sdkNameSchema = zod_1.z
    .string()
    .min(1, 'Empty sdkName parameter')
    .describe('The name of your SDK');
exports.sdkVersionSchema = zod_1.z.string().describe('The version of the SDK').default('1.0.0');
exports.apiVersionSchema = zod_1.z
    .string()
    .refine((field) => (0, semver_1.valid)(field), 'Version must follow the semantic versioning format')
    .describe('version of your API');
exports.apiNameSchema = zod_1.z
    .string()
    .min(1, 'Empty sdkName parameter')
    .describe('name of your API');
exports.specFilePathSchema = zod_1.z
    .string()
    .min(1, 'Empty specFilePath parameter')
    .describe('A local relative path or public URL for your spec file');
exports.createDocsSchema = zod_1.z
    .boolean()
    .describe(`Should developer documentation be generated?\n docs are supported for: ${(0, utils_1.constructUiArray)(languages_1.languagesWithDocsSupport.map((lang) => lang.language))}`)
    .default(false);
exports.authSchema = zod_1.z
    .array(zod_1.z.enum(['apikey', 'basic', 'bearer', 'custom', 'oauth']))
    .default([]);
exports.baseUrlSchema = zod_1.z
    .string()
    .min(1, 'Empty baseUrl parameter')
    .describe('The Base URL of your SDK')
    .optional();
const singleValidationToIgnoreSchema = zod_1.z
    .object({
    code: zod_1.z.string().describe('The rule code to ignore'),
    path: zod_1.z
        .array(zod_1.z.union([zod_1.z.string(), zod_1.z.number()]))
        .describe('Path that should be ignored')
        .optional(),
})
    .strict();
exports.validationsToIgnoreSchema = zod_1.z
    .array(singleValidationToIgnoreSchema)
    .describe('List of validation rules to ignore')
    .default([]);
exports.liblabVersionSchema = zod_1.z
    .string()
    .describe('The version of the liblab SDK Generator')
    .regex(/^(\d+)$/)
    .default('2');
var DocsOptions;
(function (DocsOptions) {
    DocsOptions["Api"] = "api";
    DocsOptions["EnhancedApiSpec"] = "enhancedApiSpec";
    DocsOptions["Snippets"] = "snippets";
})(DocsOptions || (exports.DocsOptions = DocsOptions = {}));
exports.docsOptionsSchema = zod_1.z.enum(['api', 'snippets', 'enhancedApiSpec']);
exports.docsSchema = zod_1.z
    .array(exports.docsOptionsSchema)
    .describe('Should API documentation or code snippets be generated?')
    .default([]);
const defaultGithubOrg = '';
const defaultPlatform = 'github';
exports.publishingPlatformSchema = zod_1.z
    .enum(['github', 'gitlab', 'bitbucket'])
    .describe('The platform to publish to')
    .default(defaultPlatform);
// Data that tells liblab how to publish the SDK to github
exports.publishingSchema = zod_1.z
    .object({
    githubOrg: zod_1.z
        .string()
        .describe('The GitHub organization to publish to')
        .default(defaultGithubOrg),
    platform: zod_1.z
        .enum(['github', 'gitlab', 'bitbucket'])
        .describe('The platform to publish to')
        .default(defaultPlatform),
})
    .describe('Publishing options')
    .default({
    githubOrg: defaultGithubOrg,
    platform: defaultPlatform,
});
exports.workflowsSchema = zod_1.z
    .object({
    path: zod_1.z
        .string()
        .describe('A local relative path to your arrazo specification file or a publicly reachable URL to the arrazo spec file'),
    outputName: zod_1.z.string().describe('The desired output name for the workflow').optional(),
})
    .describe('The workflow configuration')
    .optional();
const defaultStreaming = false;
const defaultPagination = false;
exports.analyticsSchema = zod_1.z
    .object({
    streaming: zod_1.z.boolean().default(defaultStreaming),
    pagination: zod_1.z.boolean().default(defaultPagination),
})
    .default({
    streaming: defaultStreaming,
    pagination: defaultPagination,
})
    .describe('Analytics options');
