"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.authenticationSchema = void 0;
const zod_1 = require("zod");
exports.authenticationSchema = zod_1.z
    .object({
    access: zod_1.z
        .object({
        prefix: zod_1.z
            .string()
            .describe('The prefix to use for the access authentication')
            .default('')
            .optional(),
    })
        .strict()
        .optional(),
    apiKey: zod_1.z
        .object({
        header: zod_1.z
            .string()
            .describe('The header to use for the api key authentication')
            .default('')
            .optional(),
    })
        .strict()
        .optional(),
    basic: zod_1.z
        .object({
        enabled: zod_1.z.boolean(),
    })
        .strict()
        .optional(),
    custom: zod_1.z
        .object({
        prefix: zod_1.z
            .string()
            .describe('The prefix to use for the custom authentication')
            .default('')
            .optional(),
    })
        .strict()
        .optional(),
    oauth: zod_1.z
        .object({
        enabled: zod_1.z.boolean().default(false).describe('Enable oauth authentication'),
        // TODO: Enable when complete https://liblab.atlassian.net/browse/CODEGEN-2222
        basic: zod_1.z.boolean().default(false).describe('Use basic authentication for the oauth token'),
        tokenEndpoint: zod_1.z
            .object({
            path: zod_1.z
                .string()
                .describe('The path to use for the oauth token endpoint. This is used to retrieve the oauth token from the server'),
            method: zod_1.z
                .enum(['get', 'post'])
                .default('post')
                .describe('The method to use for the oauth token endpoint'),
            definition: zod_1.z.object({}).passthrough().describe('The definition of the token endpoint'),
        })
            .strict()
            .optional(),
        securityScheme: zod_1.z
            .object({
            name: zod_1.z.string().describe('The name of the security scheme for the oauth'),
            definition: zod_1.z
                .object({})
                .passthrough()
                .describe('The security scheme definition for the oauth.'),
        })
            .strict()
            .optional()
            .describe('The security scheme definition for the oauth'),
    })
        .strict()
        .optional(),
})
    .strict()
    .default({});
