"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.customizationsSchema = void 0;
const zod_1 = require("zod");
const authentication_schema_1 = require("../authentication.schema");
const environment_variable_schema_1 = require("../environment-variable.schema");
const environment_schema_1 = require("../environment.schema");
const hook_dependency_schema_1 = require("../hook-dependency.schema");
const refresh_token_params_1 = require("../refresh-token-params");
const dev_container_schema_1 = require("./dev-container.schema");
const documentation_schema_1 = require("./documentation/documentation.schema");
const endpoint_customizations_schema_1 = require("./endpoint-customizations.schema");
const readme_schema_1 = require("./readme.schema");
exports.customizationsSchema = zod_1.z
    .object({
    authentication: authentication_schema_1.authenticationSchema.optional(),
    documentation: documentation_schema_1.documentationSchema.optional(),
    devContainer: dev_container_schema_1.devContainerSchema,
    environmentVariables: environment_variable_schema_1.environmentVariable.array().optional(),
    endpointCustomizations: endpoint_customizations_schema_1.endpointCustomizationSchema.optional(),
    environments: environment_schema_1.environment.array().optional(),
    generateEnv: zod_1.z.boolean().describe('Should example .env files be generated?').default(true),
    hookDependencies: hook_dependency_schema_1.hookDependency.array().optional(),
    includeOptionalSnippetParameters: zod_1.z
        .boolean()
        .describe('toggles whether optional parameters are included in code snippets in generated SDK documentation.')
        .default(true),
    inferServiceNames: zod_1.z
        .boolean()
        .describe('Should the SDKs infer service names?')
        .optional()
        .default(false),
    injectedModels: zod_1.z.array(zod_1.z.string()).describe('A list of all custom models paths').optional(),
    license: zod_1.z
        .object({
        type: zod_1.z
            .enum(['MIT', 'GPL3', 'APACHE', 'NONE', 'CUSTOM'])
            .describe('What license should the SDKs be covered under?')
            .default('NONE'),
        url: zod_1.z.string().trim().url().describe('URL for a CUSTOM license').optional(),
    })
        .strict()
        .describe('Optional configuration for licensing the SDKs')
        .optional()
        .refine((data) => (data === null || data === void 0 ? void 0 : data.type) !== 'CUSTOM' || Boolean(data.url), {
        message: 'License "CUSTOM" requires an url',
    }),
    refreshToken: refresh_token_params_1.refreshTokenParams.optional(),
    responseHeaders: zod_1.z
        .boolean()
        .describe('Should the SDKs return a response with both the data and headers?')
        .optional()
        .default(false),
    buildAllModels: zod_1.z
        .boolean()
        .describe('Should unreferenced models be built?')
        .default(false)
        .optional(),
    retry: zod_1.z
        .object({
        backOffFactor: zod_1.z
            .number()
            .positive()
            .describe('What is the exponent base used to calulate wait times?')
            .optional(),
        enabled: zod_1.z.boolean().describe('Should the SDKs include retry behavior?').optional(),
        httpCodesToRetry: zod_1.z
            .array(zod_1.z.number().int().min(200).max(599))
            .describe('What HTTP codes should the SDKs retry on?')
            .optional(),
        httpMethodsToRetry: zod_1.z
            .array(zod_1.z.enum([
            'GET',
            'POST',
            'PUT',
            'DELETE',
            'PATCH',
            'HEAD',
            'OPTIONS',
            'CONNECT',
            'TRACE',
        ]))
            .describe('What HTTP methods should the SDKs retry on?')
            .optional(),
        maxAttempts: zod_1.z
            .number()
            .describe('How many attempts should the SDKs make before giving up?')
            .optional(),
        maxDelay: zod_1.z
            .number()
            .nonnegative()
            .describe('What is the maximum time between attempts in milliseconds?')
            .optional(),
        retryDelay: zod_1.z
            .number()
            .describe('How long should the SDKs wait between attempts in milliseconds?'),
        retryDelayJitter: zod_1.z
            .number()
            .nonnegative()
            .describe('What is the maximum random jitter applied to wait times in milliseconds?')
            .optional(),
    })
        .strict()
        .describe('Retry functionality customization')
        .optional(),
    readme: readme_schema_1.readmeSchema.optional(),
})
    .strict()
    .describe('Customizations to SDKs');
