"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enhancedApiSpecIntegrationSchema = exports.ApiDocumentationProvider = void 0;
const zod_1 = require("zod");
const github_repo_name_schema_1 = require("../github-repo-name.schema");
const target_branch_schema_1 = require("../pr/github/target-branch.schema");
var ApiDocumentationProvider;
(function (ApiDocumentationProvider) {
    ApiDocumentationProvider["Mintlify"] = "mintlify";
    ApiDocumentationProvider["Readme"] = "readmeIO";
    ApiDocumentationProvider["Redocly"] = "redocly";
})(ApiDocumentationProvider || (exports.ApiDocumentationProvider = ApiDocumentationProvider = {}));
exports.enhancedApiSpecIntegrationSchema = zod_1.z
    .object({
    githubRepoName: github_repo_name_schema_1.githubRepoNameSchema,
    targetBranch: target_branch_schema_1.targetBranchSchema.optional().default('main'),
    provider: zod_1.z
        .enum([
        ApiDocumentationProvider.Mintlify,
        ApiDocumentationProvider.Redocly,
        ApiDocumentationProvider.Readme,
    ])
        .describe('Selecting the provider will enable the liblab service to generate the required files for your integration provider'),
    redocly: zod_1.z
        .object({
        openapiPath: zod_1.z.string().optional(),
    })
        .optional(),
    readmeIO: zod_1.z
        .object({
        openapiPath: zod_1.z.string().optional(),
    })
        .optional(),
    mintlify: zod_1.z
        .object({
        codeSamplesLanguages: zod_1.z
            .array(zod_1.z.string())
            .describe('Selecting the languages to enhance and include in the mintlify integration. The selected languages will override the languages shown in the mintlify UI.')
            .optional()
            .refine((val) => {
            if (!val) {
                return true;
            }
            return new Set(val).size === val.length;
        }, {
            message: 'codeSamplesLanguages must contain unique values',
        }),
    })
        .optional(),
})
    .describe('API documentation integration object');
