"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genericLanguageOptions = void 0;
const zod_1 = require("zod");
const github_repo_name_schema_1 = require("../github-repo-name.schema");
const hook_dependency_schema_1 = require("../hook-dependency.schema");
const ignore_schema_1 = require("../ignore.schema");
const target_branch_schema_1 = require("../pr/github/target-branch.schema");
const liblab_version_schema_1 = require("./liblab-version.schema");
const sdk_version_schema_1 = require("./sdk-version.schema");
exports.genericLanguageOptions = zod_1.z
    .object({
    authors: zod_1.z
        .object({
        email: zod_1.z.string().email().default('').optional(),
        name: zod_1.z.string(),
    })
        .strict()
        .array()
        .describe('The list of authors who contribute to the SDK (In TypeScript the first is the only one displayed)')
        .optional(),
    githubRepoName: github_repo_name_schema_1.githubRepoNameSchema.optional(),
    homepage: zod_1.z.string().url().optional(),
    hookDependencies: hook_dependency_schema_1.hookDependency.array().optional(),
    ignoreFiles: ignore_schema_1.ignoreSchema.optional(),
    liblabVersion: liblab_version_schema_1.liblabVersionSchema.optional(),
    renameIllegalModelProperties: zod_1.z
        .boolean()
        .describe('renames all model properties with illegal names, during the SDK generation')
        .optional(),
    sdkVersion: sdk_version_schema_1.sdkVersionSchema.optional(),
    targetBranch: target_branch_schema_1.targetBranchSchema.optional(),
})
    .strict();
