"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.javaOptionsSchema = void 0;
const zod_1 = require("zod");
const parameters_schema_1 = require("./additional-constructor-parameters/parameters.schema");
const generic_language_options_schema_1 = require("./generic-language-options.schema");
const liblab_version_schema_1 = require("./liblab-version.schema");
exports.javaOptionsSchema = zod_1.z
    .object({
    groupId: zod_1.z.string().describe('The groupId of the Java package').optional(),
    // This is currently not used, but will be in the future when we add support in code-gen
    // Leaving this in until then so the CLI just works when the code-gen feature is implemented.
    // After that this comment should be deleted.
    // https://trello.com/c/ApdisRNu
    packageName: zod_1.z.string().describe('The name of the Java package').optional(),
    artifactId: zod_1.z.string().describe('The artifactId of the Java package').optional(),
    includeKotlinSnippets: zod_1.z
        .boolean()
        .default(false)
        .describe('Include Kotlin snippets and documentation in the generated SDK'),
    developers: zod_1.z
        .array(zod_1.z.object({
        name: zod_1.z.string().describe('The name of the developer'),
        email: zod_1.z.string().email().describe('The email of the developer'),
        organization: zod_1.z.string().describe('The organization of the developer'),
        organizationUrl: zod_1.z
            .string()
            .url()
            .describe('The organization URL of the developer. It is acceptable to link to your profile on GitHub or other forges, if you do no have a website.'),
    }))
        .describe("The developers' information to add to pom.xml for project association")
        .optional(),
    additionalConstructorParameters: parameters_schema_1.additionalConstructorParametersSchema.optional(),
    ...generic_language_options_schema_1.genericLanguageOptions.shape,
    liblabVersion: liblab_version_schema_1.liblabVersionSchema.default('2'),
})
    .strict()
    .describe('Java specific options');
