"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typescriptOptionsSchema = void 0;
const zod_1 = require("zod");
const parameters_schema_1 = require("./additional-constructor-parameters/parameters.schema");
const generic_language_options_schema_1 = require("./generic-language-options.schema");
const liblab_version_schema_1 = require("./liblab-version.schema");
exports.typescriptOptionsSchema = zod_1.z
    .object({
    bundle: zod_1.z.boolean().describe('Should the SDKs be bundled?').default(true),
    denoteCommon: zod_1.z
        .boolean()
        .describe('Should the SDK mark common models with the `Common` postfix? (Useful when conflicts occur)')
        .default(false)
        .optional(),
    exportClassDefault: zod_1.z
        .boolean()
        .describe('Should the SDK export the main class as default?')
        .default(false),
    httpClient: zod_1.z
        .enum(['axios', 'fetch', 'https'])
        .describe('The HTTP client to use')
        .default('fetch'),
    npmName: zod_1.z.string().describe('The NPM package name to publish to').optional(),
    npmOrg: zod_1.z.string().describe('The NPM organization to publish to').optional(),
    additionalConstructorParameters: parameters_schema_1.additionalConstructorParametersSchema.optional(),
    ...generic_language_options_schema_1.genericLanguageOptions.shape,
    liblabVersion: liblab_version_schema_1.liblabVersionSchema.default('1'),
    generateEnumAs: zod_1.z
        .union([zod_1.z.literal('union'), zod_1.z.literal('enum')])
        .optional()
        .default('enum'),
    namingStrategy: zod_1.z.union([zod_1.z.literal('default'), zod_1.z.literal('originalPropertyNames')]).optional(),
})
    .strict()
    .describe('TypeScript specific options');
