"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.liblabSchema = void 0;
const semver_1 = require("semver");
const zod_1 = require("zod");
const languages_1 = require("../constants/languages");
const construct_ui_array_1 = require("../utils/construct-ui-array");
const customizations_schema_1 = require("./customizations/customizations.schema");
const docs_schema_1 = require("./docs.schema");
const integrations_schema_1 = require("./integrations/integrations.schema");
const language_options_schema_1 = require("./language-options/language-options.schema");
const liblab_version_schema_1 = require("./language-options/liblab-version.schema");
const language_schema_1 = require("./language.schema");
const mcp_schema_1 = require("./mcp/mcp.schema");
const publishing_schema_1 = require("./publishing/publishing.schema");
const workflows_schema_1 = require("./workflows.schema");
function customErrorMap(error, ctx) {
    switch (error.code) {
        case zod_1.z.ZodIssueCode.invalid_type: {
            if (error.received === 'undefined') {
                return { message: `Field is required!` };
            }
            break;
        }
        default: {
            return { message: ctx.defaultError };
        }
    }
    return { message: ctx.defaultError };
}
zod_1.z.setErrorMap(customErrorMap);
exports.liblabSchema = zod_1.z
    .object({
    sdkName: zod_1.z
        .string()
        .describe('The name of your SDK')
        .min(1, 'Empty sdkName parameter')
        .optional(),
    apiVersion: zod_1.z
        .string()
        .refine((field) => (0, semver_1.valid)(field), 'Version must follow the semantic versioning format')
        .describe('version of your API')
        .optional(),
    apiName: zod_1.z.string().describe('name of your API').optional(),
    specFilePath: zod_1.z
        .string()
        .min(1, 'Empty specFilePath parameter')
        .describe('A local relative path to your specification file or a publicly reachable URL to the spec file'),
    languages: language_schema_1.languageSchema,
    createDocs: zod_1.z
        .boolean()
        .describe(`Should developer documentation be generated?\n docs are supported for: ${(0, construct_ui_array_1.constructUiArray)(languages_1.languagesWithDocsSupport.map((lang) => lang.language))}`)
        .default(false)
        .optional(),
    workflows: workflows_schema_1.workflowsSchema.optional(),
    docs: docs_schema_1.docsSchema,
    auth: zod_1.z.array(zod_1.z.enum(['apikey', 'basic', 'bearer', 'custom', 'oauth'])).optional(),
    customizations: customizations_schema_1.customizationsSchema.optional(),
    baseUrl: zod_1.z
        .string()
        .describe('The Base URL of your SDK')
        .min(1, 'Empty baseUrl parameter')
        .optional(),
    languageOptions: language_options_schema_1.languageOptionsSchema.optional(),
    mcp: mcp_schema_1.mcpSchema,
    liblabVersion: liblab_version_schema_1.liblabVersionSchema.optional(), // TODO (CODEGEN-1179): Remove optional tag
    publishing: publishing_schema_1.publishingSchema.optional(),
    validationsToIgnore: zod_1.z
        .array(zod_1.z
        .object({
        code: zod_1.z.string().describe('The rule code to ignore'),
        path: zod_1.z
            .array(zod_1.z.union([zod_1.z.string(), zod_1.z.number()]))
            .describe('Path that should be ignored')
            .optional(),
    })
        .strict())
        .optional(),
    integrations: integrations_schema_1.integrationsSchema.optional(),
})
    .strict()
    .describe('The liblab Configuration File');
