"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnhancedApiSpecService = exports.DEFAULT_ENRICHED_SPEC_NAME = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const rest_1 = require("@octokit/rest");
const adm_zip_1 = tslib_1.__importDefault(require("adm-zip"));
const fs_extra_1 = require("fs-extra");
const isomorphic_git_1 = tslib_1.__importDefault(require("isomorphic-git"));
const node_1 = tslib_1.__importDefault(require("isomorphic-git/http/node"));
const node_child_process_1 = require("node:child_process");
const node_fs_1 = tslib_1.__importStar(require("node:fs"));
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const yaml_1 = tslib_1.__importDefault(require("yaml"));
const messages_1 = tslib_1.__importDefault(require("../../constants/messages"));
const paths_default_1 = require("../../constants/paths.default");
const constants_1 = require("../../lib/git/constants");
const helpers_1 = require("../../lib/helpers");
const cmds_json_1 = require("../../logs/cmds.json");
const construct_ui_array_1 = require("../../utils/construct-ui-array");
const rethrown_error_1 = require("../../utils/error/rethrown-error");
const git_platform_token_1 = require("../../utils/git-platform-token");
const get_mint_json_1 = require("../../utils/integrations/mintlify/get-mint-json");
const get_mintlify_navigation_1 = require("../../utils/integrations/mintlify/get-mintlify-navigation");
const get_mintlify_openapi_path_1 = require("../../utils/integrations/mintlify/get-mintlify-openapi-path");
const get_modified_mint_json_1 = require("../../utils/integrations/mintlify/get-modified-mint-json");
const save_enhanced_spec_in_tmp_git_1 = require("../../utils/integrations/mintlify/save-enhanced-spec-in-tmp-git");
const normalize_sdk_names_1 = require("../../utils/normalize-sdk-names");
const wrapper_utils_1 = require("../../utils/wrapper.utils");
const constants_2 = require("./constants");
exports.DEFAULT_ENRICHED_SPEC_NAME = 'enhancedApiSpec.json';
class EnhancedApiSpecService {
    constructor(analytics) {
        this.analytics = analytics;
    }
    async exportLocalEnhancedApiSpec(liblabConfig, enrichedSpec, enrichedSpecLanguages, approveAllOperations) {
        var _a, _b, _c;
        const outputName = ((_c = (_b = (_a = liblabConfig.customizations) === null || _a === void 0 ? void 0 : _a.documentation) === null || _b === void 0 ? void 0 : _b.enhancedApiSpec) === null || _c === void 0 ? void 0 : _c.customOutputName) ||
            exports.DEFAULT_ENRICHED_SPEC_NAME;
        const enrichedSpecPath = node_path_1.default.join(paths_default_1.outputDir, outputName);
        const languagesInUiFormat = enrichedSpecLanguages.map((language) => normalize_sdk_names_1.sdkNameToUiNameMapper[language]);
        const isSpecExists = (0, fs_extra_1.existsSync)(enrichedSpecPath);
        if (isSpecExists && !approveAllOperations) {
            const { overwriteEnhancedApiSpec } = await wrapper_utils_1.inquirer.prompt({
                message: cmds_json_1.BUILD.OVERWRITE_ENHANCED_SPEC_PROMPT.replace('{enhancedApiSpec}', enrichedSpecPath),
                name: 'overwriteEnhancedApiSpec',
                type: 'confirm',
            });
            if (!overwriteEnhancedApiSpec) {
                this.analytics.logEvent({
                    reason: 'User chose not to overwrite enhancedApiSpec file while running build',
                    status: 'abort',
                });
                return;
            }
        }
        // suffix can be: .json, .yaml or .yml (enhancedSpecDocumentationOptionsSchema)
        const enhancedApiSpecContentToWrite = enrichedSpecPath.endsWith('.json')
            ? JSON.stringify(enrichedSpec, undefined, 2)
            : yaml_1.default.stringify(enrichedSpec);
        try {
            (0, fs_extra_1.writeFileSync)(enrichedSpecPath, enhancedApiSpecContentToWrite);
            core_1.ux.stdout(messages_1.default.SUCCESS.GENERATED_ENRICHED_SPEC_SUCCESSFULLY(enrichedSpecPath, (0, construct_ui_array_1.constructUiArray)(languagesInUiFormat)));
        }
        catch (error) {
            (0, helpers_1.debugLog)('Failed to write files @EnrichSpec helper', error);
            throw new rethrown_error_1.RethrownError(messages_1.default.ERROR.ERROR_DUE_TO_FAILURE_TO_ENHANCE_SPEC({
                outputName,
                outputPath: enrichedSpecPath,
                reason: error.message,
            }), error);
        }
    }
    async publish(liblabConfig, buildUrl, enhancedSpec, enhancedLanguages) {
        const liblabGithubToken = (0, git_platform_token_1.getLiblabGitPlatformToken)('github');
        if (!liblabGithubToken) {
            throw new Error(cmds_json_1.PR.ERROR.LIBLAB_GITHUB_TOKEN_MISSING);
        }
        const octokit = new rest_1.Octokit({ auth: liblabGithubToken });
        const repoUrl = `https://github.com/${liblabConfig.publishing.githubOrg}/${liblabConfig.integrations.enhancedApiSpec.githubRepoName}.git`;
        const log = this.getPrLogHeader(liblabConfig.integrations.enhancedApiSpec.provider);
        core_1.ux.stdout(log);
        let user;
        try {
            const { data } = await octokit.users.getAuthenticated();
            user = data;
        }
        catch {
            throw new Error(`Unable to access github repository: ${repoUrl}`);
        }
        (0, fs_extra_1.emptyDirSync)(paths_default_1.TMP_GIR_DIR_NAME);
        // clone repo
        await isomorphic_git_1.default.clone({
            fs: node_fs_1.default,
            http: node_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            url: repoUrl,
            onAuthFailure() {
                throw new Error(`Unable to access github repository: ${repoUrl}`);
            },
            onAuth(url) {
                (0, helpers_1.debugLog)('git#clone: Authenticating for:', url);
                return {
                    username: liblabConfig.publishing.githubOrg,
                    password: liblabGithubToken,
                };
            },
        });
        const ref = `liblab-api-documentation-update-${Date.now()}`;
        const creatingBranchLog = cmds_json_1.PR.INFO.PR_CREATING_NEW_BRANCH.replace('{language}', 'API documentation');
        core_1.ux.stdout(creatingBranchLog);
        const repoOwnerLog = cmds_json_1.PR.INFO.PR_OWNER.replace('{owner}', liblabConfig.publishing.githubOrg);
        core_1.ux.stdout(repoOwnerLog);
        const prRepoLog = cmds_json_1.PR.INFO.PR_REPOSITORY.replace('{repository}', liblabConfig.integrations.enhancedApiSpec.githubRepoName);
        core_1.ux.stdout(prRepoLog);
        const prBranchLog = cmds_json_1.PR.INFO.PR_BRANCH.replace('{branchName}', ref);
        core_1.ux.stdout(prBranchLog);
        await isomorphic_git_1.default.checkout({
            fs: node_fs_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            ref: liblabConfig.integrations.enhancedApiSpec.targetBranch,
        });
        await isomorphic_git_1.default.branch({
            fs: node_fs_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            ref,
            checkout: true,
        });
        await isomorphic_git_1.default.checkout({
            fs: node_fs_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            ref,
        });
        this.integrateEnhancedSpec(liblabConfig, enhancedSpec, enhancedLanguages);
        await this.publishWithGit({ ref, user, liblabConfig, liblabGithubToken });
        const { data } = await octokit.pulls.create({
            base: liblabConfig.integrations.enhancedApiSpec.targetBranch,
            body: `Liblab documentation update from: ${buildUrl}`,
            head: ref,
            owner: liblabConfig.publishing.githubOrg,
            repo: liblabConfig.integrations.enhancedApiSpec.githubRepoName,
            title: 'Liblab API documentation update',
        });
        (0, fs_extra_1.rmSync)(paths_default_1.TMP_GIR_DIR_NAME, { recursive: true });
        const message = cmds_json_1.PR.INFO.PR_CREATED.replace('{language}', 'Enhanced API spec');
        const relativePathInGH = data.url.slice(constants_2.GH_API_URL_PREFIX.length);
        const relativePullRequestUrl = relativePathInGH.replace('pulls', 'pull');
        const url = `https://github.com/${relativePullRequestUrl}`;
        const messageWithUrl = `${message}: ${url}`;
        core_1.ux.stdout(messageWithUrl);
    }
    /**
     * Redocly can split openapi specs into components, this function will check if the cloned repo is using
     * splitted openapi
     */
    checkIfRepoHasSplitOpenApiSpec() {
        const zip = new adm_zip_1.default();
        zip.addLocalFolder(paths_default_1.TMP_GIR_DIR_NAME);
        let isOpenApiSplit = false;
        zip.forEach((entry) => {
            if (entry.entryName.includes(node_path_1.default.join('openapi', 'paths'))) {
                isOpenApiSplit = true;
            }
        });
        return isOpenApiSplit;
    }
    getPrLogHeader(provider) {
        return `\n-${provider.toUpperCase()} API DOCUMENTATION INTEGRATION --------------------------------------`;
    }
    getRedoclyOpenapiPath(liblabConfig) {
        var _a, _b;
        if (!(0, fs_extra_1.existsSync)(constants_2.REDOC_YAML_PATH)) {
            return constants_2.LOCAL_OPENAPI_FILE_IN_REDOCLY_REPO;
        }
        const redoclyConfigInYamlFormat = (0, node_fs_1.readFileSync)(constants_2.REDOC_YAML_PATH, 'utf8');
        const redoclyConfigAsJson = yaml_1.default.parse(redoclyConfigInYamlFormat);
        if (!liblabConfig.apiName) {
            throw new Error('Api name must be provided to use custom api path');
        }
        if (!((_a = redoclyConfigAsJson.apis[liblabConfig.apiName]) === null || _a === void 0 ? void 0 : _a.root)) {
            throw new Error(`Invalid root configuration in redocly.yaml api name is: ${liblabConfig.apiName} available apis in redocly.yaml are: ${(0, construct_ui_array_1.constructUiArray)(Object.keys(redoclyConfigAsJson.apis))}`);
        }
        return (_b = redoclyConfigAsJson.apis[liblabConfig.apiName]) === null || _b === void 0 ? void 0 : _b.root;
    }
    injectRedoclyUpdates(enhancedApiSpec, openapiPath) {
        const isSplitOpenApi = this.checkIfRepoHasSplitOpenApiSpec();
        const openApiPathInTempGitDir = node_path_1.default.join(paths_default_1.TMP_GIR_DIR_NAME, openapiPath);
        const isFileExists = (0, fs_extra_1.existsSync)(openApiPathInTempGitDir);
        if (!isFileExists) {
            throw new Error(`openapi spec was not found in path: ${openapiPath}, Unable to integrate with redocly`);
        }
        const isJson = openApiPathInTempGitDir.endsWith('.json');
        if (isJson) {
            (0, fs_extra_1.writeFileSync)(openApiPathInTempGitDir, JSON.stringify(enhancedApiSpec, undefined, 2));
        }
        const isYaml = openApiPathInTempGitDir.endsWith('.yaml') || openApiPathInTempGitDir.endsWith('.yml');
        if (isYaml) {
            (0, fs_extra_1.writeFileSync)(openApiPathInTempGitDir, yaml_1.default.stringify(enhancedApiSpec, undefined, 2));
        }
        if (!isJson && !isYaml) {
            throw new Error('unsorted format for openapi in redocly repo');
        }
        if (isSplitOpenApi) {
            // Split the openapi
            (0, node_child_process_1.execSync)(`npx @redocly/cli split ${openApiPathInTempGitDir} --outDir="${constants_2.LOCAL_OPENAPI_DIR_IN_REDOCLY_REPO}"`, { stdio: 'ignore' });
        }
    }
    /**
     * This function provides integration with the providers for the enhanced openapi spec.
     * the provider's input will be prepared in the local cloned repo
     */
    integrateEnhancedSpec(liblabConfig, enhancedSpec, enhancedLanguages) {
        switch (liblabConfig.integrations.enhancedApiSpec.provider) {
            case 'mintlify': {
                this.integrateWithMintlify(enhancedSpec, liblabConfig, enhancedLanguages);
                break;
            }
            case 'redocly': {
                this.integrateWithRedocly(enhancedSpec, liblabConfig);
                break;
            }
            default: {
                this.integrateWithReadmeIO(enhancedSpec, liblabConfig);
                break;
            }
        }
    }
    integrateWithMintlify(enhancedSpec, liblabConfig, enhancedLanguages) {
        const mintJson = (0, get_mint_json_1.getMintJson)();
        const openapiPath = (0, get_mintlify_openapi_path_1.getMintlifyOpenapiPath)(mintJson);
        // delete openapi directory
        const openapiComponents = openapiPath.split(node_path_1.default.sep);
        const openapiDir = openapiComponents.slice(0, -1).join(node_path_1.default.sep);
        (0, fs_extra_1.rmSync)(openapiDir, { recursive: true });
        (0, fs_extra_1.mkdirSync)(openapiDir);
        (0, save_enhanced_spec_in_tmp_git_1.saveEnhancedSpecInTmpGit)(openapiPath, enhancedSpec);
        const openapiNavigation = (0, get_mintlify_navigation_1.getMintlifyNavigation)({ openapiDir, openapiPath });
        const updatedMintJson = (0, get_modified_mint_json_1.getModifiedMintJson)(mintJson, openapiNavigation, liblabConfig, enhancedLanguages);
        (0, fs_extra_1.writeFileSync)(constants_2.MINT_JSON_PATH, JSON.stringify(updatedMintJson, undefined, 2));
    }
    integrateWithReadmeIO(enhancedApiSpec, liblabConfig) {
        var _a, _b, _c;
        const openapiPath = ((_c = (_b = (_a = liblabConfig.integrations) === null || _a === void 0 ? void 0 : _a.enhancedApiSpec) === null || _b === void 0 ? void 0 : _b.readmeIO) === null || _c === void 0 ? void 0 : _c.openapiPath) || 'openapi.json';
        const openApiPathInTempGitDir = node_path_1.default.join(paths_default_1.TMP_GIR_DIR_NAME, openapiPath);
        const isFileExists = (0, fs_extra_1.existsSync)(openApiPathInTempGitDir);
        if (!isFileExists) {
            throw new Error(`Unable to integrate with ReadMe.IO due to OpenAPI Spec not found in the path: ${openapiPath}. Please revise the OpenAPI path within the Integrations object in your liblab config.`);
        }
        const isJson = openApiPathInTempGitDir.endsWith('.json');
        if (isJson) {
            (0, fs_extra_1.writeFileSync)(openApiPathInTempGitDir, JSON.stringify(enhancedApiSpec, undefined, 2));
        }
        const isYaml = openApiPathInTempGitDir.endsWith('.yaml') || openApiPathInTempGitDir.endsWith('.yml');
        if (isYaml) {
            (0, fs_extra_1.writeFileSync)(openApiPathInTempGitDir, yaml_1.default.stringify(enhancedApiSpec, undefined, 2));
        }
    }
    integrateWithRedocly(enhancedApiSpec, liblabConfig) {
        var _a, _b, _c;
        const redoclyOpenapiPath = ((_c = (_b = (_a = liblabConfig.integrations) === null || _a === void 0 ? void 0 : _a.enhancedApiSpec) === null || _b === void 0 ? void 0 : _b.redocly) === null || _c === void 0 ? void 0 : _c.openapiPath) ||
            this.getRedoclyOpenapiPath(liblabConfig);
        this.injectRedoclyUpdates(enhancedApiSpec, redoclyOpenapiPath);
    }
    async publishWithGit({ ref, user, liblabConfig, liblabGithubToken, }) {
        await this.stageAllChangedFiles(paths_default_1.TMP_GIR_DIR_NAME);
        core_1.ux.stdout(cmds_json_1.PR.INFO.PR_COMMITTING_FILES);
        await isomorphic_git_1.default.commit({
            fs: node_fs_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            message: 'liblab API documentation update',
            author: {
                name: user.name || constants_1.DEFAULT_COMMIT_AUTHOR,
                email: user.email || constants_1.DEFAULT_COMMIT_EMAIL,
            },
        });
        await isomorphic_git_1.default.push({
            fs: node_fs_1.default,
            http: node_1.default,
            dir: paths_default_1.TMP_GIR_DIR_NAME,
            ref,
            onAuth(url) {
                core_1.ux.stdout('git#push: Authenticating for:', url);
                return {
                    username: liblabConfig.publishing.githubOrg,
                    password: liblabGithubToken,
                };
            },
        });
    }
    async stageAllChangedFiles(repoDir) {
        const statusMatrix = await isomorphic_git_1.default.statusMatrix({ fs: node_fs_1.default, dir: repoDir });
        const updatePromises = statusMatrix.reduce((acc, [filepath, _headStatus, workdirStatus, stageStatus]) => {
            if (workdirStatus === 0 && stageStatus !== 0) {
                // File is deleted in the working directory but not staged for deletion, add to removePromises
                const promise = isomorphic_git_1.default.remove({ fs: node_fs_1.default, dir: repoDir, filepath });
                acc.push(promise);
            }
            else if (workdirStatus !== stageStatus) {
                // File is modified (or new) and needs to be staged, add to addPromises
                acc.push(isomorphic_git_1.default.add({ fs: node_fs_1.default, dir: repoDir, filepath }));
            }
            return acc;
        }, []);
        await Promise.all(updatePromises);
    }
}
exports.EnhancedApiSpecService = EnhancedApiSpecService;
