"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Artifact = exports.ArtifactStatus = void 0;
const fs_1 = require("./fs");
const http_1 = require("./http");
var ArtifactStatus;
(function (ArtifactStatus) {
    ArtifactStatus["FAIL"] = "FAIL";
    ArtifactStatus["IN_PROGRESS"] = "IN_PROGRESS";
    ArtifactStatus["SUCCESS"] = "SUCCESS";
})(ArtifactStatus || (exports.ArtifactStatus = ArtifactStatus = {}));
function fromArtifactResponseLanguage(language) {
    if (!language) {
        return undefined;
    }
    const languageMap = {
        CSHARP: 'csharp',
        GO: 'go',
        JAVA: 'java',
        MCP: 'mcp',
        PHP: 'php',
        PYTHON: 'python',
        SWIFT: 'swift',
        TERRAFORM: 'terraform',
        TYPESCRIPT: 'typescript',
    };
    return languageMap[language];
}
class Artifact {
    constructor(artifactResponse) {
        this.artifactResponse = artifactResponse;
        this.fsService = new fs_1.FsService();
        this.httpService = new http_1.HttpService();
    }
    get displayName() {
        var _a, _b;
        const language = fromArtifactResponseLanguage((_b = (_a = this.artifactResponse) === null || _a === void 0 ? void 0 : _a.sdk) === null || _b === void 0 ? void 0 : _b.language);
        if (language === undefined) {
            return 'undefined';
        }
        const languagesToDisplayName = {
            csharp: 'C#',
            go: 'Go',
            java: 'Java',
            mcp: 'MCP',
            php: 'PHP',
            python: 'Python',
            swift: 'Swift',
            terraform: 'Terraform',
            typescript: 'Typescript',
        };
        return languagesToDisplayName[language];
    }
    get filename() {
        var _a, _b;
        const language = fromArtifactResponseLanguage((_b = (_a = this.artifactResponse) === null || _a === void 0 ? void 0 : _a.sdk) === null || _b === void 0 ? void 0 : _b.language);
        if (language === undefined) {
            return 'undefined';
        }
        const languagesToDisplayName = {
            csharp: 'csharp',
            go: 'go',
            java: 'java',
            mcp: 'mcp',
            php: 'php',
            python: 'python',
            swift: 'swift',
            terraform: 'terraform',
            typescript: 'typescript',
        };
        return languagesToDisplayName[language];
    }
    get status() {
        return this.artifactResponse.status;
    }
    async download() {
        if (!this.artifactResponse.artifactUrl) {
            throw new Error(`cannot download file, url not defined`);
        }
        const artifactBuffer = await this.httpService.getArtifact(this.artifactResponse.artifactUrl);
        await this.fsService.writeArtifactBufferToDisk(this.filename, artifactBuffer);
    }
}
exports.Artifact = Artifact;
