"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Auth = void 0;
const tslib_1 = require("tslib");
const sdk_1 = require("@liblab/sdk");
const open_1 = tslib_1.__importDefault(require("open"));
const index_1 = tslib_1.__importDefault(require("../../../constants/env/index"));
const auth0_1 = require("./auth0");
const token_storage_1 = require("./token-storage");
class Auth {
    constructor() {
        this.auth0 = new auth0_1.Auth0();
        this.tokenStorage = new token_storage_1.TokenStorage();
        // Private constructor to enforce singleton pattern
    }
    static getInstance() {
        if (!Auth.instance) {
            Auth.instance = new Auth();
        }
        return Auth.instance;
    }
    async getAccessToken() {
        const tokenProviders = [
            async () => this.tokenStorage.getAccessToken(),
            async () => process.env.LIBLAB_TOKEN || null,
            async () => this.auth0.getAccessToken(),
        ];
        for (const getToken of tokenProviders) {
            try {
                const token = await getToken();
                const currentUser = await this.getCurrentUser(token);
                if (token && currentUser) {
                    await this.tokenStorage.setToken(token);
                    return token;
                }
            }
            catch {
                // Handle error if needed
            }
        }
        return null;
    }
    async logout() {
        await (0, open_1.default)(auth0_1.AUTH_0_LOGOUT_TARGET);
        await this.tokenStorage.clearToken();
    }
    async getCurrentUser(accessToken) {
        if (!accessToken) {
            return null;
        }
        const liblab = new sdk_1.Liblab({
            environment: index_1.default.baseUrl,
            accessToken,
        });
        try {
            return await liblab.user.getCurrentUser();
        }
        catch {
            return null;
        }
    }
}
exports.Auth = Auth;
