"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Auth0 = exports.AUTH_0_LOGOUT_TARGET = void 0;
const tslib_1 = require("tslib");
const open_1 = tslib_1.__importDefault(require("open"));
const openid_client_1 = require("openid-client");
const index_1 = tslib_1.__importDefault(require("../../../constants/env/index"));
const { auth0ClientId, auth0Issuer, auth0audience } = index_1.default;
const AUTH_0_GRANT_TYPE = 'urn:ietf:params:oauth:grant-type:device_code';
const AUTH_0_SCOPES = 'openid email';
const ONE_DAY_IN_MILLISECONDS = 24 * 3600 * 1000;
exports.AUTH_0_LOGOUT_TARGET = `${auth0Issuer}/oidc/logout`;
class Auth0 {
    async getAccessToken() {
        const deviceFlowHandler = await this.getAuth0Client();
        await (0, open_1.default)(deviceFlowHandler.verification_uri_complete);
        const tokenSet = await deviceFlowHandler.poll();
        if (!tokenSet.access_token) {
            return null;
        }
        return tokenSet.access_token;
    }
    async getAuth0Client() {
        const issuer = await openid_client_1.Issuer.discover(auth0Issuer);
        const auth0Client = new issuer.Client({
            client_id: auth0ClientId,
            grant_types: [AUTH_0_GRANT_TYPE],
            max_age: ONE_DAY_IN_MILLISECONDS,
            token_endpoint_auth_method: 'none',
        });
        return auth0Client.deviceAuthorization({
            audience: auth0audience,
            scope: AUTH_0_SCOPES,
        });
    }
}
exports.Auth0 = Auth0;
