"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenStorage = void 0;
const tslib_1 = require("tslib");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const index_1 = tslib_1.__importDefault(require("../../../constants/env/index"));
const fs_1 = require("../fs");
const ocliff_config_1 = require("../ocliff-config");
const { environment } = index_1.default;
const envName = environment.toLowerCase();
const liblabTokenKey = envName === 'production' ? 'token' : `${envName}-token`;
const TOKEN_FILE_NAME = 'token.json';
class TokenStorage {
    constructor() {
        this.fs = new fs_1.FsService();
    }
    async clearToken() {
        const tokenDir = this.getTokenDir();
        await this.fs.writeJsonFile(node_path_1.default.join(tokenDir, TOKEN_FILE_NAME), {});
    }
    async getAccessToken() {
        await this.ensureTokenFileExists();
        const tokenFilePath = this.getTokenFilePath();
        const tokens = await this.fs.readJsonFile(tokenFilePath);
        return tokens[liblabTokenKey];
    }
    async setToken(newToken) {
        await this.ensureTokenFileExists();
        const tokenFilePath = this.getTokenFilePath();
        const tokens = await this.fs.readJsonFile(tokenFilePath);
        tokens[liblabTokenKey] = newToken;
        try {
            await this.fs.writeJsonFile(tokenFilePath, tokens);
        }
        catch (error) {
            console.error('Error writing token to filesystem. The CLI may require you to login again:', error);
        }
    }
    async ensureTokenFileExists() {
        const tokenDir = this.getTokenDir();
        await this.fs.ensureFileExists(tokenDir, TOKEN_FILE_NAME, JSON.stringify({}));
    }
    getTokenDir() {
        const config = ocliff_config_1.OCliffConfig.getInstance().getConfig();
        return config.dataDir;
    }
    getTokenFilePath() {
        const tokenDir = this.getTokenDir();
        return node_path_1.default.join(tokenDir, TOKEN_FILE_NAME);
    }
}
exports.TokenStorage = TokenStorage;
