"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildLogger = void 0;
const tslib_1 = require("tslib");
const node_crypto_1 = require("node:crypto");
const env_1 = tslib_1.__importDefault(require("../../constants/env"));
const auth_1 = require("./auth/auth");
const types_1 = require("./build/types");
const logging_1 = require("./logging/logging");
const logging_events_1 = require("./logging/logging-events");
const net_1 = require("./net");
class BuildLogger {
    constructor(command, config, argv) {
        this.command = command;
        this.config = config;
        this.argv = argv;
        this.auth = auth_1.Auth.getInstance();
        this.logging = new logging_1.Logging();
    }
    logEvent({ config, artifacts, build, status, duration, isFreeBuild }) {
        var _a, _b, _c;
        const event = {
            ...this.getBaseEvent(),
            artifactIds: artifacts.map((artifact) => artifact.id.toString()),
            artifacts,
            build,
            org: (_c = (_b = (_a = this.auth.currentUser) === null || _a === void 0 ? void 0 : _a.orgs) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c.org,
            status,
            apiName: config.apiName,
            apiVersion: config.apiVersion,
            auth: config.auth || [],
            customizations: config.customizations,
            languages: config.languages,
            publishing: config.publishing,
            specFilePath: config.specFilePath,
            isFreeBuild: Boolean(isFreeBuild),
            pagination: Boolean(config.analytics.pagination),
            sdkName: config.sdkName,
            specFormat: types_1.AllowedSpecFormats.OpenAPI,
            streaming: Boolean(config.analytics.streaming),
            validIssues: [],
            buildDuration: duration,
            buildId: build.id,
        };
        this.logging.log(event, { datadog: true, mixpanel: true });
    }
    getBaseEvent() {
        return {
            ...this.getEnvironmentMetadata(),
            action: this.command.id,
            description: this.command.description || '',
            currentUser: this.auth.currentUser,
            platform: process.platform,
            arch: this.config.arch,
            argv: this.argv,
            cliVersion: this.config.version,
            eventName: logging_events_1.EventName.BUILD,
            user: this.auth.currentUser,
            version: this.config.version,
            shell: this.config.shell,
            sessionId: logging_1.Logging.sessionId,
        };
    }
    getEnvironmentMetadata() {
        return {
            env: env_1.default.environment,
            insertId: (0, node_crypto_1.randomUUID)(),
            ipAddress: (0, net_1.getLocalIp)(),
            os: process.platform,
            time: Date.now(),
        };
    }
}
exports.BuildLogger = BuildLogger;
