"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildUx = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const spinnies_1 = tslib_1.__importDefault(require("@trufflesuite/spinnies"));
const env_1 = tslib_1.__importDefault(require("../../constants/env"));
const artifact_1 = require("./artifact");
const string_1 = require("./string");
const { dashboardUrl } = env_1.default;
class BuildUx {
    constructor() {
        this.spinners = new spinnies_1.default();
    }
    buildComplete(successfulArtifacts) {
        core_1.ux.stdout([
            `\n✨ Successfully generated ${(0, string_1.pluralize)('SDK', successfulArtifacts.length)} for ${successfulArtifacts.map((artifact) => { var _a; return (_a = artifact.artifactResponse.sdk) === null || _a === void 0 ? void 0 : _a.language; }).join(', ')}! ♡ You can find ${successfulArtifacts.length > 1 ? 'them' : 'it'} inside: ./output`,
        ]);
    }
    startBuild(api, build) {
        var _a;
        (_a = build.artifacts) === null || _a === void 0 ? void 0 : _a.filter((artifact) => Boolean(artifact.sdk)).map((artifact) => new artifact_1.Artifact(artifact).displayName).forEach((language) => {
            this.addSpinner(language, `Building ${language}`);
        });
        core_1.ux.stdout(`Your SDKs are being generated. Visit the ${(0, string_1.bold)(`liblab portal (${dashboardUrl}/apis/${api.slug}/builds/${build.id})`)} to view more details on your build(s).\n`);
    }
    updateBuildsProgress(artifacts) {
        artifacts
            .filter((artifact) => Boolean(artifact.sdk))
            .map((artifact) => new artifact_1.Artifact(artifact))
            .forEach((artifact) => {
            this.concludeSpinner(artifact.displayName, artifact.artifactResponse.status);
        });
    }
    addSpinner(name, text) {
        this.spinners.add(name, {
            prefixColor: 'yellow',
            text,
        });
    }
    concludeSpinner(name, status) {
        var _a;
        // Check to make sure the status is complete and the spinner isn't already concluded
        if (status === 'IN_PROGRESS' || ((_a = this.spinners.pick(name)) === null || _a === void 0 ? void 0 : _a.status) !== 'spinning') {
            return;
        }
        if (status === 'FAIL') {
            this.spinners.fail(name, { prefixColor: 'red', text: `${name} failed` });
        }
        else if (status === 'SUCCESS') {
            this.spinners.succeed(name, { prefixColor: 'green', text: `${name} succeeded` });
        }
    }
}
exports.BuildUx = BuildUx;
