"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocsIntegrations = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const spinnies_1 = tslib_1.__importDefault(require("@trufflesuite/spinnies"));
const node_fs_1 = require("node:fs");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const yaml_1 = tslib_1.__importDefault(require("yaml"));
const paths_default_1 = require("../../../constants/paths.default");
const enhanced_api_spec_schema_1 = require("../../../schemas/integrations/enhanced-api-spec.schema");
const spec_enhancer_1 = tslib_1.__importDefault(require("../../../spec-enhancer"));
const api_1 = require("../api");
const github_docs_pr_data_1 = require("../pr/pr-data/github-docs-pr-data");
const pr_workflow_1 = require("../pr/pr-workflow");
const docs_integrations_ux_1 = require("./docs-integrations-ux");
const mintlify_integration_1 = require("./mintlify-integration");
const SPEC_WITH_SNIPPETS_FILENAME = 'enhancedApiSpec.json';
const SPEC_WITH_SNIPPETS_FILE_PATH = node_path_1.default.join(paths_default_1.outputDir, SPEC_WITH_SNIPPETS_FILENAME);
const { LIBLAB_GITHUB_TOKEN } = process.env;
class DocsIntegrations {
    static async run(build, liblabConfig, apiResponse, spec) {
        var _a, _b;
        const { enhancedSpec, languages } = await (0, spec_enhancer_1.default)(build, liblabConfig, spec);
        await this.exportLocal(enhancedSpec, languages, false);
        await api_1.LiblabApi.getInstance().createEnhancedSpec('enhancedApiSpec.json', build.id);
        if (((_a = liblabConfig.integrations) === null || _a === void 0 ? void 0 : _a.enhancedApiSpec) && ((_b = liblabConfig.publishing) === null || _b === void 0 ? void 0 : _b.githubOrg)) {
            await this.publish(build, liblabConfig, apiResponse, liblabConfig.integrations.enhancedApiSpec.provider, enhancedSpec);
        }
    }
    static async exportLocal(spec, languages, overwrite) {
        if ((0, node_fs_1.existsSync)(SPEC_WITH_SNIPPETS_FILE_PATH) && !overwrite) {
            const shouldOverwrite = await new docs_integrations_ux_1.DocsIntegrationsUX().confirmOverwrite();
            if (!shouldOverwrite) {
                return;
            }
        }
        const enhancedApiSpecContentToWrite = SPEC_WITH_SNIPPETS_FILE_PATH.endsWith('.json')
            ? JSON.stringify(spec, undefined, 2)
            : yaml_1.default.stringify(spec);
        (0, node_fs_1.writeFileSync)(SPEC_WITH_SNIPPETS_FILE_PATH, enhancedApiSpecContentToWrite);
    }
    // TODO: This type comes from the old config schema!
    static async integrate(provider, enhancedApiSpec, liblabConfig) {
        switch (provider) {
            case enhanced_api_spec_schema_1.ApiDocumentationProvider.Mintlify: {
                await new mintlify_integration_1.MintlifyIntegration().run(enhancedApiSpec, liblabConfig);
                break;
            }
            case enhanced_api_spec_schema_1.ApiDocumentationProvider.Readme: {
                // TODO: Implement readme integration
                break;
            }
            case enhanced_api_spec_schema_1.ApiDocumentationProvider.Redocly: {
                // TODO: Implement redocly integration
                break;
            }
            default: {
                throw new Error(`Unsupported git platform: ${provider}`);
            }
        }
    }
    static async publish(build, liblabConfig, apiResponse, provider, spec) {
        if (!LIBLAB_GITHUB_TOKEN) {
            throw new Error('the LIBLAB_GITHUB_TOKEN environment variable is not set');
        }
        const prData = new github_docs_pr_data_1.GithubDocsPrData(LIBLAB_GITHUB_TOKEN, liblabConfig.languages[0], liblabConfig, apiResponse, build);
        const { htmlUrl } = await pr_workflow_1.PrWorkflow.createPr('github', LIBLAB_GITHUB_TOKEN, prData, async () => {
            core_1.ux.stdout('-MINTLIFY API DOCUMENTATION INTEGRATION --------------------------------------\n');
            core_1.ux.stdout('Creating a new branch for API documentation:');
            core_1.ux.stdout(`\tOwner: ${prData.org}`);
            core_1.ux.stdout(`\tRepository: ${prData.repo}`);
            core_1.ux.stdout(`\tBranch Name: ${prData.branchName}]\n`);
            core_1.ux.stdout(`Authenticating for: https://github.com/${prData.org}/${prData.repo}.git\n`);
            this.spinners.add('mintlify-integration', {
                prefixColor: 'yellow',
                text: `Running mintlify integration\n`,
            });
            await this.integrate(provider, spec, liblabConfig);
            this.spinners.succeed('mintlify-integration', { text: 'Mintlify integration complete\n' });
        });
        core_1.ux.stdout(`Successfully created PR for Enhanced API spec: ${htmlUrl}`);
    }
}
exports.DocsIntegrations = DocsIntegrations;
DocsIntegrations.spinners = new spinnies_1.default();
