"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FsService = void 0;
const tslib_1 = require("tslib");
const adm_zip_1 = tslib_1.__importDefault(require("adm-zip"));
const node_fs_1 = require("node:fs");
const promises_1 = require("node:fs/promises");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const yaml_1 = tslib_1.__importDefault(require("yaml"));
class FsService {
    async ensureFileExists(dirPath, fileName, defaultContent = '') {
        const fullPath = node_path_1.default.join(dirPath, fileName);
        if (!(0, node_fs_1.existsSync)(fullPath)) {
            await (0, promises_1.mkdir)(node_path_1.default.dirname(fullPath), { recursive: true });
            await (0, promises_1.writeFile)(fullPath, defaultContent);
        }
    }
    /**
     * A map from environment names (e.g. 'production', 'staging') to their corresponding access tokens.
     * The environment name is lowercased and used as a key with '-token' appended
     * (e.g. 'token' for production, 'staging-token' for staging)
     */
    async readJsonFile(filePath) {
        const tokenFile = await (0, promises_1.readFile)(filePath, 'utf8');
        const storedTokens = JSON.parse(tokenFile);
        return storedTokens;
    }
    async readYamlFile(filePath) {
        const fileContent = await (0, promises_1.readFile)(filePath, 'utf8');
        return yaml_1.default.parse(fileContent);
    }
    async writeArtifactBufferToDisk(filename, artifactBuffer) {
        const zipArchive = new adm_zip_1.default(artifactBuffer);
        zipArchive.extractAllTo(node_path_1.default.join(process.cwd(), `./output/${filename}`), true);
    }
    async writeJsonFile(filePath, content) {
        await (0, promises_1.writeFile)(filePath, JSON.stringify(content, null, 2));
    }
    async writeObjectFile(filePath, content) {
        await (filePath.endsWith('.yaml')
            ? (0, promises_1.writeFile)(filePath, yaml_1.default.stringify(content, null, 2))
            : (0, promises_1.writeFile)(filePath, JSON.stringify(content, null, 2)));
    }
}
exports.FsService = FsService;
