"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseDatadogEventAdapter = void 0;
const tslib_1 = require("tslib");
const datadog = tslib_1.__importStar(require("@datadog/datadog-api-client"));
const node_crypto_1 = require("node:crypto");
const env_1 = tslib_1.__importDefault(require("../../../../constants/env"));
const datadog_1 = require("../../../../lib/datadog");
const datadogEnv = datadog_1.LiblabEnvToDatadogEnvMap[env_1.default.environment] || '';
const configuration = datadog.client.createConfiguration({
    authMethods: {
        apiKeyAuth: env_1.default.datadogClientToken,
    },
});
class BaseDatadogEventAdapter {
    constructor(event) {
        var _a;
        this.event = event;
        this.datadogApi = new datadog.v2.LogsApi(configuration);
        this.tags = {
            UserId: ((_a = this.event.user) === null || _a === void 0 ? void 0 : _a.id.toString()) || '',
            Event: this.event.eventName,
        };
    }
    createAdditionalProperties() {
        return {
            $insert_id: (0, node_crypto_1.randomUUID)(),
            $os: '',
            args: '',
            cli_version: '',
            env: '',
            ip_address: '',
            time: '',
        };
    }
    async log() {
        const eventBody = this.createEventBody();
        this.datadogApi.submitLog({
            body: [eventBody],
        });
    }
    buildDatadogMessage() {
        return Object.entries(this.tags)
            .map(([tagKey, tagValue]) => {
            if (!tagValue) {
                return null;
            }
            return `[${tagKey}]: ${tagValue}`;
        })
            .filter((tag) => tag !== null)
            .join(' ');
    }
    createEventBody() {
        return {
            additionalProperties: this.createAdditionalProperties(),
            ddsource: 'nodejs',
            ddtags: `env:${datadogEnv}, version:${this.event.version}`,
            message: this.buildDatadogMessage(),
            service: 'cli',
        };
    }
}
exports.BaseDatadogEventAdapter = BaseDatadogEventAdapter;
