"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logging = void 0;
const node_crypto_1 = require("node:crypto");
const datadog_build_event_adapter_1 = require("./datadog-adapters/datadog-build-event-adapter");
const logging_events_1 = require("./logging-events");
const mixpanel_adapter_factory_1 = require("./mixpanel-adapters/mixpanel-adapter-factory");
const datadogAdapters = {
    [logging_events_1.EventName.BUILD]: datadog_build_event_adapter_1.DatadogBuildEventAdapter,
};
class Logging {
    log(event, params) {
        const adapters = this.getAdapters(event, params);
        adapters.forEach((adapter) => adapter.log());
    }
    getAdapters(event, params) {
        return [
            params.datadog ? new datadogAdapters[event.eventName](event) : null,
            params.mixpanel ? mixpanel_adapter_factory_1.MixpanelAdapterFactory.getAdapter(event) : null,
        ].filter((adapter) => adapter !== null);
    }
}
exports.Logging = Logging;
Logging.sessionId = (0, node_crypto_1.randomUUID)();
