"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasePrData = void 0;
const tslib_1 = require("tslib");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const paths_default_1 = require("../../../../constants/paths.default");
const pr_utils_1 = require("../../../../utils/pr.utils");
const LOCAL_REPO_PATH = '.temp-git';
class BasePrData {
    constructor(token, language, liblabConfig) {
        var _a, _b, _c, _d, _e;
        this.body = this.createPrBody(liblabConfig.sdkVersion, liblabConfig.apiVersion);
        this.branchName = this.createBranchName(liblabConfig.sdkVersion);
        this.language = language;
        this.repo = ((_b = (_a = liblabConfig.languageOptions) === null || _a === void 0 ? void 0 : _a[language]) === null || _b === void 0 ? void 0 : _b.githubRepoName) || '';
        this.repoUrl = '';
        this.targetBranch = ((_d = (_c = liblabConfig.languageOptions) === null || _c === void 0 ? void 0 : _c[language]) === null || _d === void 0 ? void 0 : _d.targetBranch) || 'main';
        this.commitMessage = this.createCommitMessage(liblabConfig.sdkVersion);
        this.filePathsToRemove = [];
        this.org = (_e = liblabConfig.publishing) === null || _e === void 0 ? void 0 : _e.githubOrg;
        this.token = token;
        this.username = this.org;
        this.title = `liblab SDK update v${liblabConfig.sdkVersion}`;
    }
    async init() {
        this.filePathsToRemove = await this.createFilePathsForRemoval(this.language);
    }
    // this is the same for all languages
    createBranchName(sdkVersion) {
        const currentDate = new Date();
        if (!sdkVersion) {
            return `liblab-codegen-${currentDate.getTime()}`;
        }
        return `v${sdkVersion}-${currentDate.getTime()}`;
    }
    // this is the same for all languages
    createCommitMessage(sdkVersion) {
        return `liblab SDK update for version v${sdkVersion}`;
    }
    // this is the same for all languages
    async createFilePathsForRemoval(language) {
        const tempLocalGitRepoPath = node_path_1.default.join(process.cwd(), LOCAL_REPO_PATH, language);
        const localManifestPath = node_path_1.default.join(paths_default_1.outputDir, language, '.manifest.json');
        const remoteManifestPath = node_path_1.default.join(tempLocalGitRepoPath, '.manifest.json');
        const filePathsToRemove = await (0, pr_utils_1.getLocalToRemoteManifestDiff)({
            language,
            localManifestPath,
            remoteManifestPath,
        });
        return filePathsToRemove;
    }
    // this is the same for all languages
    createPrBody(apiVersion, sdkVersion) {
        return ('## Automatically generated PR with SDK updates by liblab.\n\n' +
            `- API version: **v${apiVersion}**\n` +
            `- SDK version: **v${sdkVersion}**`);
    }
}
exports.BasePrData = BasePrData;
