"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSpecFile = getSpecFile;
const file_utils_1 = require("../../utils/file.utils");
const spec_service_1 = require("../spec/spec.service");
function removeScriptsFromPostmanCollection(collection) {
    const cloned = structuredClone(collection);
    function cleanItem(originalItem) {
        const item = { ...originalItem };
        if (item.event) {
            item.event = item.event.filter((event) => !['prerequest', 'test'].includes(event.listen));
        }
        if (Array.isArray(item.item)) {
            item.item = item.item.map((child) => cleanItem(child));
        }
        return item;
    }
    if (cloned.event) {
        cloned.event = cloned.event.filter((event) => !['prerequest', 'test'].includes(event.listen));
    }
    if (Array.isArray(cloned.item)) {
        cloned.item = cloned.item.map((element) => cleanItem(element));
    }
    return cloned;
}
const POSTMAN_SCHEMA_CHECK_REGEX = /^https?:\/\/schema.(get)?postman.com\//;
function convertSpecToJson(spec) {
    try {
        return JSON.parse(spec);
    }
    catch {
        return null;
    }
}
function isPostmanSpec(spec) {
    var _a;
    const specAsJson = convertSpecToJson(spec);
    if (!specAsJson)
        return false;
    const schemaUrl = (_a = specAsJson === null || specAsJson === void 0 ? void 0 : specAsJson.info) === null || _a === void 0 ? void 0 : _a.schema;
    return typeof schemaUrl === 'string' && POSTMAN_SCHEMA_CHECK_REGEX.test(schemaUrl);
}
/**
 * Retrieves and processes an API specification file based on the LibLab configuration.
 *
 * @param liblabConfig - The validated LibLab configuration object containing spec file details
 * @returns Promise that resolves to an object containing:
 *   - spec: The contents of the API specification file
 *   - specFileFormat: The identified format of the spec file (e.g. OpenAPI, AsyncAPI)
 * @throws {Error} If the spec file cannot be read or has an unsupported format
 */
async function getSpecFile(liblabConfig) {
    const spec = await new spec_service_1.SpecService().getSpecFile(liblabConfig);
    const specFileFormat = (0, file_utils_1.identifyFileContentFormat)(spec);
    if (isPostmanSpec(spec)) {
        // we don't currently support scripts in postman collections and they trigger security errors on request, so we remove them here.
        return {
            spec: removeScriptsFromPostmanCollection(spec),
            specFileFormat,
        };
    }
    return { spec, specFileFormat };
}
