"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkflowsService = void 0;
const tslib_1 = require("tslib");
const axios_1 = require("axios");
const messages_1 = tslib_1.__importDefault(require("../constants/messages"));
const rethrown_error_1 = require("../utils/error/rethrown-error");
const file_utils_1 = require("../utils/file.utils");
class WorkflowsService {
    constructor(liblabClient) {
        this.liblabClient = liblabClient;
    }
    async uploadWorkFlows(liblabConfig, apiId) {
        const workflowsFileContents = await this.getWorkflowsFile(liblabConfig.workflows.path);
        await this.liblabClient.uploadWorkflows(apiId, workflowsFileContents, liblabConfig.workflows.outputName);
    }
    async getWorkflowsFile(workflowsPath) {
        try {
            return await (0, file_utils_1.getFile)(workflowsPath);
        }
        catch (specFileReadError) {
            if (specFileReadError instanceof axios_1.AxiosError) {
                throw new rethrown_error_1.RethrownError(messages_1.default.ERROR.BUILD_FAILED_WORKFLOWS_URL_INVALID, specFileReadError);
            }
            throw new rethrown_error_1.RethrownError(messages_1.default.ERROR.BUILD_FAILED_WORKFLOWS_PATH_INVALID, specFileReadError);
        }
    }
}
exports.WorkflowsService = WorkflowsService;
