"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchSdkArtifacts = fetchSdkArtifacts;
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
async function fetchSdkArtifacts(artifacts) {
    const promises = artifacts.map((artifact) => axios_1.default.get(artifact.artifactUrl, { responseType: 'arraybuffer' }));
    const settled = await Promise.allSettled(promises);
    const { resolved, failed } = settled.reduce((acc, curr, index) => {
        const { language } = artifacts[index].sdk;
        if (curr.status === 'fulfilled') {
            acc.resolved.push({ language, data: curr.value.data });
        }
        else {
            acc.failed.push({ language, reason: curr.reason, status: curr.status });
        }
        return acc;
    }, {
        resolved: [],
        failed: [],
    });
    if (failed.length > 0) {
        const sdks = failed.map((data) => data.language);
        throw new Error(`Failed to retrieve the following sdks: ${sdks.join(',')}`);
    }
    return resolved;
}
