"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEnhancedReadmeIoSpec = getEnhancedReadmeIoSpec;
const file_utils_1 = require("../../../utils/file.utils");
const normalize_sdk_names_1 = require("../../../utils/normalize-sdk-names");
const constants_1 = require("../../constants");
const snippets_1 = require("../snippets");
const get_root_level_enhancement_1 = require("./get-root-level-enhancement");
/**
 *
 * @param language provided language
 * @returns {string} language in readmeIo format
 */
const getReadmeLanguage = (language) => {
    if (language === 'TypeScript' || language === 'typescript')
        return 'node';
    // @ts-expect-error - if we get a falsy value we default to the language
    return normalize_sdk_names_1.uiNameToRealNameMapper[language] || language;
};
function getEnhancedReadmeIoSpec(languageMap, spec) {
    var _a;
    let specAsJs = (0, file_utils_1.getParseFileContent)(spec);
    const languagesInSpec = ((_a = specAsJs[constants_1.X_README_OPENAPI_KEY]) === null || _a === void 0 ? void 0 : _a[constants_1.X_README_ROOT_LEVEL_NESTED_SAMPLES_LANGUAGES_KEY]) ||
        specAsJs[constants_1.ROOT_LEVEL_SAMPLES_KEY] ||
        [];
    const languagesInReadmeFormat = [...languagesInSpec, ...Object.keys(languageMap)].map((language) => getReadmeLanguage(language));
    const rootLevelEnhancement = (0, get_root_level_enhancement_1.getReadmeIoRootLevelLanguagesObject)(specAsJs, languagesInReadmeFormat);
    specAsJs = { ...specAsJs, ...rootLevelEnhancement };
    const snippets = new snippets_1.Snippets(languageMap);
    snippets.forEachOperation(({ pathKey, httpMethod, language, languageSnippets }) => {
        var _a, _b, _c, _d;
        const operationObject = specAsJs.paths[pathKey][httpMethod];
        let readmeEnhancement = (_a = operationObject[constants_1.X_README_OPENAPI_KEY]) === null || _a === void 0 ? void 0 : _a[constants_1.README_CODE_SAMPLES_OPERATION_LEVEL_KEY];
        if (!readmeEnhancement) {
            specAsJs.paths[pathKey][httpMethod][constants_1.X_README_OPENAPI_KEY] = {
                [constants_1.README_CODE_SAMPLES_OPERATION_LEVEL_KEY]: [],
            };
        }
        readmeEnhancement =
            (_b = operationObject[constants_1.X_README_OPENAPI_KEY]) === null || _b === void 0 ? void 0 : _b[constants_1.README_CODE_SAMPLES_OPERATION_LEVEL_KEY];
        const enhancementWithoutLanguage = readmeEnhancement.filter((codeSample) => codeSample.language !== language);
        const code = (_d = (_c = languageSnippets.endpoints) === null || _c === void 0 ? void 0 : _c[pathKey]) === null || _d === void 0 ? void 0 : _d[httpMethod];
        if (!code) {
            return;
        }
        specAsJs.paths[pathKey][httpMethod][constants_1.X_README_OPENAPI_KEY][constants_1.README_CODE_SAMPLES_OPERATION_LEVEL_KEY] = [...enhancementWithoutLanguage, { code, language: getReadmeLanguage(language) }];
    });
    return specAsJs;
}
