"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEnhancedOAS = getEnhancedOAS;
const file_utils_1 = require("../../utils/file.utils");
const normalize_sdk_names_1 = require("../../utils/normalize-sdk-names");
const constants_1 = require("../constants");
const get_spec_enhancement_type_1 = require("../get-spec-enhancement-type");
const get_enhance_readme_spec_1 = require("./get-enhance-readme-spec");
const snippets_1 = require("./snippets");
function getEnhancedOAS(enhancement, languageMap, spec) {
    if (enhancement === get_spec_enhancement_type_1.Enhancement.ReadmeIo) {
        return (0, get_enhance_readme_spec_1.getEnhancedReadmeIoSpec)(languageMap, spec);
    }
    const snippets = new snippets_1.Snippets(languageMap);
    const specAsJs = (0, file_utils_1.getParseFileContent)(spec);
    snippets.forEachOperation(({ pathKey, httpMethod, language, languageSnippets }) => {
        var _a, _b;
        if (!((_a = specAsJs.paths[pathKey]) === null || _a === void 0 ? void 0 : _a[httpMethod])) {
            return;
        }
        const operationObject = specAsJs.paths[pathKey][httpMethod];
        if (!operationObject[constants_1.CODE_SAMPLES_KEY]) {
            operationObject[constants_1.CODE_SAMPLES_KEY] = [];
        }
        const source = (_b = languageSnippets.endpoints[pathKey]) === null || _b === void 0 ? void 0 : _b[httpMethod];
        if (!source) {
            return;
        }
        const languageUiName = normalize_sdk_names_1.sdkNameToUiNameMapper[language];
        const enhancementWithoutLanguage = operationObject[constants_1.CODE_SAMPLES_KEY].filter((codeSample) => codeSample.lang !== languageUiName);
        operationObject[constants_1.CODE_SAMPLES_KEY] = [
            ...enhancementWithoutLanguage,
            { source, lang: languageUiName },
        ];
    });
    return specAsJs;
}
