"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJsonSnippetsFromMdFiles = getJsonSnippetsFromMdFiles;
const get_http_method_from_last_component_of_file_name_1 = require("./get-http-method-from-last-component-of-file-name");
const get_paths_components_from_izip_entry_1 = require("./get-paths-components-from-izip-entry");
const get_snippets_entries_from_archive_1 = require("./get-snippets-entries-from-archive");
const structure_oas_path_from_md_content_path_1 = require("./structure-oas-path-from-md-content-path");
function getJsonSnippetsFromMdFiles(language, archive) {
    const endpoints = {};
    const onlyDocumentationSnippets = (0, get_snippets_entries_from_archive_1.getSnippetsEntriesFromArchive)(archive);
    if (onlyDocumentationSnippets.length === 0) {
        throw new Error(`Invalid snippets files for language: ${language}`);
    }
    onlyDocumentationSnippets.forEach((entry) => {
        const { fileName, lastNameComponent } = (0, get_paths_components_from_izip_entry_1.getPathComponentsFromIzipEntry)(entry);
        if (!(lastNameComponent === null || lastNameComponent === void 0 ? void 0 : lastNameComponent.includes('.md')) || !fileName) {
            throw new Error('Unable to process snippets output');
        }
        const httpMethod = (0, get_http_method_from_last_component_of_file_name_1.getHttpMethodFromLastComponentOfFileName)(lastNameComponent);
        const pathInOas = (0, structure_oas_path_from_md_content_path_1.structureOASPathFromMdContentPath)({ fileName, lastNameComponent });
        const mdContent = entry
            .getData()
            .toString('utf8')
            .slice(language.length + 3, -4)
            .trim()
            // Liblab's API recognize <?php and forbids passing it over in the request payload
            .replace('<?php\n\n', '');
        if (!endpoints[pathInOas]) {
            endpoints[pathInOas] = {
                [httpMethod]: mdContent,
            };
            return;
        }
        endpoints[pathInOas][httpMethod] = mdContent;
    });
    return endpoints;
}
