"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSupportedLanguagesForSpecEnrichment = getSupportedLanguagesForSpecEnrichment;
const tslib_1 = require("tslib");
const messages_1 = tslib_1.__importDefault(require("../constants/messages"));
const liblab_config_warnings_1 = require("../validators/liblab-config/liblab-config-warnings");
/**
 * This method iterates over the provided artifacts then iterates over the  @constant {Array<{language: string, version?: string}>} UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC
 * In order to see if the artifact belongs to a supported language for api spec enhancement
 * @returns {ArtifactWithSdk[]} filtered array of the sdk artifacts
 */
function getSupportedArtifactsForSpecEnrichments(onlySuccessfulSdkArtifacts, liblabConfig) {
    return onlySuccessfulSdkArtifacts.filter((artifact) => {
        const isUnSupportedLanguage = liblab_config_warnings_1.UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC.find(({ language, version }) => {
            var _a, _b;
            const isUnsupportedLanguage = artifact.sdk.language === language.toUpperCase();
            if (isUnsupportedLanguage &&
                (!version || ((_b = (_a = liblabConfig.languageOptions) === null || _a === void 0 ? void 0 : _a[language]) === null || _b === void 0 ? void 0 : _b.liblabVersion) === version)) {
                return true;
            }
            return false;
        });
        return !isUnSupportedLanguage;
    });
}
/**
 * This method iterates over the provided artifacts then iterates over the  @constant {Array<{language: string, version?: string}>} UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC
 * In order to see if the artifact belongs to a supported language for api spec enhancement
 * @param onlySuccessfulSdkArtifacts
 * @param liblabConfig
 * @returns {ArtifactWithSdk[]} filtered array of the sdk artifacts
 */
function getSupportedLanguagesForSpecEnrichment(liblabConfig, build) {
    var _a, _b, _c, _d;
    const onlySuccessfulSdkArtifacts = (_a = build.artifacts) === null || _a === void 0 ? void 0 : _a.filter((artifact) => artifact.sdk && artifact.status === 'SUCCESS');
    if (!onlySuccessfulSdkArtifacts || onlySuccessfulSdkArtifacts.length === 0) {
        throw new Error(messages_1.default.ERROR.ENHANCE_SPEC_MISSING_SUCCESSFUL_SDKS(((_d = (_c = (_b = liblabConfig.customizations) === null || _b === void 0 ? void 0 : _b.documentation) === null || _c === void 0 ? void 0 : _c.enhancedApiSpec) === null || _d === void 0 ? void 0 : _d.customOutputName) ||
            'enhancedApiSpec'));
    }
    const artifactsWithLanguageSupportForSpecEnrichment = getSupportedArtifactsForSpecEnrichments(onlySuccessfulSdkArtifacts, liblabConfig);
    return artifactsWithLanguageSupportForSpecEnrichment;
}
