"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyOauthCustomization = applyOauthCustomization;
const oauth_customization_error_1 = require("./error/oauth-customization-error");
const json_utils_1 = require("./json.utils");
function customizeSecurityScheme(parsedSpec, securityScheme) {
    const components = parsedSpec.components || {};
    const securitySchemes = components.securitySchemes || {};
    securitySchemes[securityScheme.name] = securityScheme.definition;
    Object.assign(parsedSpec.components, components);
}
function customizeOauthEndpoint(parsedSpec, tokenEndpoint) {
    const { method, path, definition } = tokenEndpoint;
    const originalPath = parsedSpec.paths[path] || {};
    const originalMethod = originalPath[method] || {};
    originalPath[method] = {
        ...originalMethod,
        ...definition,
    };
    Object.assign(parsedSpec.paths, { ...parsedSpec.paths, [path]: originalPath });
}
function applyBasicOauthCustomization(parsedSpec) {
    var _a;
    const securitySchemes = (_a = parsedSpec.components) === null || _a === void 0 ? void 0 : _a.securitySchemes;
    if (!securitySchemes) {
        throw new oauth_customization_error_1.OauthCustomizationError('The OAuth security scheme must be defined in the spec.');
    }
    Object.values(securitySchemes).forEach((value) => {
        if (value && value instanceof Object) {
            Object.assign(value, { ...value, 'x-liblab-basic-oauth': true });
        }
    });
}
/**
 * This method mutates the parsed spec
 * Apply the OAuth customization to the parsed spec
 */
function applyOauthCustomization(parsedSpec, oauthCustomization) {
    const modifiedSpec = (0, json_utils_1.deepCopy)(parsedSpec);
    if (!oauthCustomization.enabled) {
        return modifiedSpec;
    }
    if (oauthCustomization.securityScheme) {
        customizeSecurityScheme(modifiedSpec, oauthCustomization.securityScheme);
    }
    if (oauthCustomization.tokenEndpoint) {
        customizeOauthEndpoint(modifiedSpec, oauthCustomization.tokenEndpoint);
    }
    if (oauthCustomization.basic) {
        applyBasicOauthCustomization(modifiedSpec);
    }
    return modifiedSpec;
}
