"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLiblabGitPlatformToken = exports.warnAboutLegacyGithubToken = void 0;
const core_1 = require("@oclif/core");
/**
 * Get the GitHub token from the environment variables.
 * Supports the new LIBLAB_GITHUB_TOKEN variable name and legacy GITHUB_TOKEN variable name.
 */
const warnAboutLegacyGithubToken = () => {
    if (process.env.GITHUB_TOKEN && !process.env.LIBLAB_GITHUB_TOKEN) {
        core_1.ux.stdout('Warning: Using the GITHUB_TOKEN environment variable with liblab is deprecated. Please use LIBLAB_GITHUB_TOKEN instead. \nSee our documentation for more details at https://developers.liblab.com/integrate-with-cicd/pr-creation/#the-pr-creation-process');
    }
};
exports.warnAboutLegacyGithubToken = warnAboutLegacyGithubToken;
const getLiblabGitPlatformToken = (platform) => {
    let token;
    switch (platform) {
        case 'bitbucket': {
            token = process.env.LIBLAB_BITBUCKET_TOKEN;
            break;
        }
        case 'gitlab': {
            token = process.env.LIBLAB_GITLAB_TOKEN;
            break;
        }
        default: {
            (0, exports.warnAboutLegacyGithubToken)();
            token = process.env.LIBLAB_GITHUB_TOKEN || process.env.GITHUB_TOKEN;
            break;
        }
    }
    return token;
};
exports.getLiblabGitPlatformToken = getLiblabGitPlatformToken;
