"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMintlifyNavigation = void 0;
const node_child_process_1 = require("node:child_process");
const helpers_1 = require("../../../lib/helpers");
/**
 * This function will run mintlify's scraper nad return the output which is a suggestion for the openapi navigation items;
 * Child process return will look like:
 *  navigation object suggestion:
    [
      {
        "group": "pets",
        "pages": [
          "api-reference/pets/list-all-pets",
          "api-reference/pets/create-a-pet",
          "api-reference/pets/info-for-a-specific-pet"
        ]
    }
  ]
 * @returns Parsed navigation array
 */
const getMintlifyNavigation = ({ openapiPath, openapiDir, }) => {
    try {
        const scraperOutput = (0, node_child_process_1.execSync)(`npx @mintlify/scraping@latest openapi-file ${openapiPath} -o ${openapiDir}`, { encoding: 'utf8' });
        const openapiNavigation = JSON.parse(scraperOutput.replace('navigation object suggestion:', ''));
        return openapiNavigation;
    }
    catch (error) {
        (0, helpers_1.debugLog)(`Failed to scrape openapi reason: ${error.message}`);
        throw new Error('Failed to scrape openapi');
    }
};
exports.getMintlifyNavigation = getMintlifyNavigation;
