"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getModifiedMintJson = void 0;
const tslib_1 = require("tslib");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const normalize_sdk_names_1 = require("../../normalize-sdk-names");
const getMintlifyObjectWithNavigation = (mintJson, openapiNavigation) => {
    const newMintJson = { ...mintJson };
    const openapiNavigationWithoutTempGitPrefix = openapiNavigation.map((item) => ({
        ...item,
        pages: item.pages.map((page) => {
            const pageComponents = page.split(node_path_1.default.sep);
            return pageComponents.slice(pageComponents.indexOf('.temp-git') + 1).join(node_path_1.default.sep);
        }),
    }));
    const indexOfNavigation = newMintJson.navigation.findIndex((navItem) => navItem.group === 'api reference');
    newMintJson.navigation.splice(indexOfNavigation, indexOfNavigation === -1 ? 0 : 1, {
        group: 'api reference',
        pages: openapiNavigationWithoutTempGitPrefix,
    });
    return newMintJson;
};
const getMintlifyObjectWithApiModifications = (mintJson, liblabConfig, enhancedLanguages) => {
    var _a, _b, _c, _d, _e, _f;
    const languages = ((_a = liblabConfig.integrations.enhancedApiSpec.mintlify) === null || _a === void 0 ? void 0 : _a.codeSamplesLanguages) &&
        ((_c = (_b = liblabConfig.integrations.enhancedApiSpec.mintlify) === null || _b === void 0 ? void 0 : _b.codeSamplesLanguages) === null || _c === void 0 ? void 0 : _c.length) > 0
        ? liblabConfig.integrations.enhancedApiSpec.mintlify.codeSamplesLanguages
        : enhancedLanguages;
    // Bash should always be included Regardless the selection of the user
    languages.unshift('bash');
    const languagesInUiFormat = languages.map(
    // @ts-expect-error - if we dont support name format, have it the way its written
    (language) => { var _a; return (_a = normalize_sdk_names_1.sdkNameToUiNameMapper[language]) !== null && _a !== void 0 ? _a : language; });
    const updatedJson = {
        ...mintJson,
        api: {
            ...mintJson.api,
            request: {
                ...(_d = mintJson.api) === null || _d === void 0 ? void 0 : _d.request,
                example: {
                    ...(_f = (_e = mintJson.api) === null || _e === void 0 ? void 0 : _e.request) === null || _f === void 0 ? void 0 : _f.example,
                    languages: languagesInUiFormat,
                },
            },
        },
    };
    return updatedJson;
};
const getModifiedMintJson = (mintJson, openapiNavigation, liblabConfig, enhancedLanguages) => {
    const mintlifyWithNavigation = getMintlifyObjectWithNavigation(mintJson, openapiNavigation);
    return getMintlifyObjectWithApiModifications(mintlifyWithNavigation, liblabConfig, enhancedLanguages);
};
exports.getModifiedMintJson = getModifiedMintJson;
