"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInfoTable = void 0;
const tslib_1 = require("tslib");
const tty_table_1 = tslib_1.__importDefault(require("tty-table"));
const env_1 = tslib_1.__importDefault(require("../../constants/env"));
const { baseUrl, environment } = env_1.default;
const DESCRIPTION = 'Description';
const VALUE = 'Value';
const VARIABLE = 'Variable';
const getInfoTable = (currentUser) => {
    // Define the columns
    const header = [
        {
            value: VARIABLE,
            headerColor: 'cyan',
            align: 'left',
            width: 20,
        },
        {
            value: DESCRIPTION,
            headerColor: 'cyan',
            align: 'left',
            width: 50,
        },
        {
            value: VALUE,
            headerColor: 'cyan',
            align: 'left',
            width: 30,
        },
    ];
    const rows = [
        {
            [VARIABLE]: 'environment',
            [DESCRIPTION]: 'The value of the LIBLAB_ENVIRONMENT env variable.\n' +
                'To change it, define it as a env variable in your system.',
            [VALUE]: environment,
        },
        {
            [VARIABLE]: 'base URL',
            [DESCRIPTION]: 'The url that is going to be used by the cli \n' +
                'to make network requests to the liblab API.\n' +
                'To change it, set the environment to one of:\n' +
                'development | staging | production.',
            [VALUE]: baseUrl,
        },
        {
            [VARIABLE]: 'User Email',
            [DESCRIPTION]: 'Current authenticated user email',
            [VALUE]: currentUser.email,
        },
    ];
    return (0, tty_table_1.default)(header, rows);
};
exports.getInfoTable = getInfoTable;
