"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTokensTable = void 0;
const tslib_1 = require("tslib");
const tty_table_1 = tslib_1.__importDefault(require("tty-table"));
const getTokensTable = (tokensResponse) => {
    const tokensData = tokensResponse
        .map(({ name, expiresAt }) => ({ name, expiresAt: new Date(expiresAt) }))
        .sort((a, b) => a.expiresAt.getTime() - b.expiresAt.getTime());
    const header = [
        {
            value: 'Token',
            headerColor: 'cyan',
            align: 'left',
            width: 50,
        },
        {
            value: 'Expiry Date',
            headerColor: 'cyan',
            align: 'left',
            width: 30,
        },
    ];
    const tableData = tokensData.map(({ name, expiresAt }) => {
        const isExpired = expiresAt.getTime() < Date.now();
        const token = isExpired ? `${name} (Expired)` : name;
        return {
            Token: token,
            'Expiry Date': expiresAt.toLocaleString(),
        };
    });
    return (0, tty_table_1.default)(header, tableData);
};
exports.getTokensTable = getTokensTable;
