"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMarker = exports.pluralize = void 0;
exports.getColoredText = getColoredText;
function getColoredText(color, text) {
    switch (color) {
        case 'blue': {
            return `\u001B[94m${text}\u001B[0m`;
        }
        case 'gray': {
            return `\u001B[90m${text}\u001B[0m`;
        }
        case 'green': {
            return `\u001B[92m${text}\u001B[0m`;
        }
        case 'red': {
            return `\u001B[91m${text}\u001B[0m`;
        }
        case 'yellow': {
            return `\u001B[93m${text}\u001B[0m`;
        }
        default: {
            return text;
        }
    }
}
/**
 * Pluralize a word based on a preceding number.
 * Works only for regular English plurals.
 * @example pluralize('credit', 1) // 'credit'
 * @example pluralize('credit', 2) // 'credits'
 * @param word Word to pluralize
 * @param count Preceding number
 */
const pluralize = (word, count) => `${word}${count > 1 ? 's' : ''}`;
exports.pluralize = pluralize;
const getMarker = (severity) => {
    switch (severity) {
        case 'error': {
            return getColoredText('red', '✗');
        }
        case 'hint': {
            return getColoredText('blue', '💡');
        }
        case 'info': {
            return getColoredText('green', 'ℹ');
        }
        case 'success': {
            return getColoredText('green', '✓');
        }
        case 'warning': {
            return getColoredText('yellow', '⚠');
        }
        default: {
            return '';
        }
    }
};
exports.getMarker = getMarker;
