"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatViolationPath = formatViolationPath;
exports.formatViolationGroup = formatViolationGroup;
const is_url_1 = require("../is-url");
const text_utils_1 = require("../text.utils");
function formatViolationPath(violation, specFilePath, isLocalSpec) {
    const { path, range } = violation;
    const maxSegments = 7;
    const jsonPath = path.length > maxSegments ? `.../${path.slice(-maxSegments).join('/')}` : path.join('/');
    if (!isLocalSpec) {
        return (0, text_utils_1.getColoredText)('gray', `  ${jsonPath}`);
    }
    const linkToLine = `${specFilePath}:${range.start.line + 1}:${range.start.character}`;
    return `  ${(0, text_utils_1.getColoredText)('gray', jsonPath)} (${linkToLine})`;
}
function formatViolationGroup(violations, specFilePath) {
    const { severity, message } = violations[0];
    const instanceCountText = violations.length > 1 ? ` (${violations.length})` : '';
    const messageText = `${message}${instanceCountText}`;
    const output = [`${(0, text_utils_1.getMarker)(severity)} ${messageText}`];
    const isLocalSpec = !(0, is_url_1.isUrl)(specFilePath);
    violations.forEach((violation) => output.push(formatViolationPath(violation, specFilePath, isLocalSpec)));
    return output.join('\n');
}
