"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC = void 0;
exports.getCreateDocsDeprecationWarning = getCreateDocsDeprecationWarning;
exports.getLanguagesWithoutDocSupportWarning = getLanguagesWithoutDocSupportWarning;
exports.getLanguagesWithoutEnhancedApiSpecSupportWarning = getLanguagesWithoutEnhancedApiSpecSupportWarning;
const tslib_1 = require("tslib");
const languages_1 = require("../../constants/languages");
const messages_1 = tslib_1.__importDefault(require("../../constants/messages"));
const construct_ui_array_1 = require("../../utils/construct-ui-array");
const docs_utils_1 = require("../../utils/docs.utils");
const liblab_version_1 = require("../../utils/liblab-version");
const normalize_sdk_names_1 = require("../../utils/normalize-sdk-names");
exports.UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC = [
    { language: 'typescript', version: '1' },
    { language: 'python', version: '1' },
    { language: 'java', version: '1' },
    { language: 'swift' },
];
function getCreateDocsDeprecationWarning(createDocs) {
    if (createDocs === undefined) {
        return null;
    }
    return {
        property: 'createDocs',
        message: messages_1.default.WARNING.CREATE_DOCS_DEPRECATED,
    };
}
function getLanguagesWithoutDocSupportWarning(configData) {
    try {
        const { languages } = configData;
        const languagesWithLiblabVersion = languages.map((lang) => ({
            language: lang,
            liblabVersion: (0, liblab_version_1.getLiblabVersion)(configData, lang),
        }));
        const requestedLanguagesWithoutDocSupport = languagesWithLiblabVersion.filter((lang) => !languages_1.languagesWithDocsSupport.some((docLang) => docLang.language === lang.language && docLang.liblabVersion === lang.liblabVersion));
        if (requestedLanguagesWithoutDocSupport.length > 0 && (0, docs_utils_1.shouldGenerateApiDocs)(configData)) {
            const languagesWithVersion = requestedLanguagesWithoutDocSupport.map((lang) => `${normalize_sdk_names_1.sdkNameToUiNameMapper[lang.language]} v${lang.liblabVersion}`);
            const message = messages_1.default.WARNING.DOCS_NOT_SUPPORTS_LANGUAGES((0, construct_ui_array_1.constructUiArray)(languagesWithVersion));
            return {
                message,
            };
        }
        return null;
    }
    catch {
        return null;
    }
}
function getLanguagesWithoutEnhancedApiSpecSupportWarning(configData) {
    try {
        const { languages } = configData;
        const unsupportedLanguages = exports.UNSUPPORTED_LANGUAGES_FOR_ENHANCED_API_SPEC.filter(({ language }) => languages.includes(language));
        const unsupportedVersions = unsupportedLanguages.filter((unsupportedLanguage) => {
            var _a;
            const languageOptions = (_a = configData.languageOptions) === null || _a === void 0 ? void 0 : _a[unsupportedLanguage.language];
            if (!languageOptions) {
                return true;
            }
            return (!unsupportedLanguage.version ||
                languageOptions.liblabVersion === unsupportedLanguage.version);
        });
        const warningMessages = unsupportedVersions.map(({ language, version }) => ({
            message: messages_1.default.WARNING.ENHANCED_SPEC_NOT_SUPPORTS_LANGUAGES(normalize_sdk_names_1.sdkNameToUiNameMapper[language], version),
            property: 'docs',
        }));
        return warningMessages.length > 0 ? warningMessages : null;
    }
    catch {
        return null;
    }
}
